# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

LABEL_TO_VOLUME_MAPPING_METADATA = Metadata(
    id="a8de8237605262064e9a5abfe0dd83ad86664dd4.boutiques",
    name="label-to-volume-mapping",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


LabelToVolumeMappingRibbonConstrainedParameters = typing.TypedDict('LabelToVolumeMappingRibbonConstrainedParameters', {
    "@type": typing.NotRequired[typing.Literal["ribbon_constrained"]],
    "inner_surf": InputPathType,
    "outer_surf": InputPathType,
    "opt_voxel_subdiv_subdiv_num": typing.NotRequired[int | None],
    "opt_greedy": bool,
    "opt_thick_columns": bool,
})
LabelToVolumeMappingRibbonConstrainedParametersTagged = typing.TypedDict('LabelToVolumeMappingRibbonConstrainedParametersTagged', {
    "@type": typing.Literal["ribbon_constrained"],
    "inner_surf": InputPathType,
    "outer_surf": InputPathType,
    "opt_voxel_subdiv_subdiv_num": typing.NotRequired[int | None],
    "opt_greedy": bool,
    "opt_thick_columns": bool,
})


LabelToVolumeMappingParameters = typing.TypedDict('LabelToVolumeMappingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/label-to-volume-mapping"]],
    "label": InputPathType,
    "surface": InputPathType,
    "volume_space": InputPathType,
    "volume_out": str,
    "opt_nearest_vertex_distance": typing.NotRequired[float | None],
    "ribbon_constrained": typing.NotRequired[LabelToVolumeMappingRibbonConstrainedParameters | None],
})
LabelToVolumeMappingParametersTagged = typing.TypedDict('LabelToVolumeMappingParametersTagged', {
    "@type": typing.Literal["workbench/label-to-volume-mapping"],
    "label": InputPathType,
    "surface": InputPathType,
    "volume_space": InputPathType,
    "volume_out": str,
    "opt_nearest_vertex_distance": typing.NotRequired[float | None],
    "ribbon_constrained": typing.NotRequired[LabelToVolumeMappingRibbonConstrainedParameters | None],
})


def label_to_volume_mapping_ribbon_constrained_params(
    inner_surf: InputPathType,
    outer_surf: InputPathType,
    opt_voxel_subdiv_subdiv_num: int | None = None,
    opt_greedy: bool = False,
    opt_thick_columns: bool = False,
) -> LabelToVolumeMappingRibbonConstrainedParametersTagged:
    """
    Build parameters.
    
    Args:
        inner_surf: the inner surface of the ribbon.
        outer_surf: the outer surface of the ribbon.
        opt_voxel_subdiv_subdiv_num: voxel divisions while estimating voxel\
            weights: number of subdivisions, default 3.
        opt_greedy: also put labels in voxels with less than 50% partial volume\
            (legacy behavior).
        opt_thick_columns: use overlapping columns (legacy method).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "ribbon_constrained",
        "inner_surf": inner_surf,
        "outer_surf": outer_surf,
        "opt_greedy": opt_greedy,
        "opt_thick_columns": opt_thick_columns,
    }
    if opt_voxel_subdiv_subdiv_num is not None:
        params["opt_voxel_subdiv_subdiv_num"] = opt_voxel_subdiv_subdiv_num
    return params


def label_to_volume_mapping_ribbon_constrained_cargs(
    params: LabelToVolumeMappingRibbonConstrainedParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-ribbon-constrained")
    cargs.append(execution.input_file(params.get("inner_surf", None)))
    cargs.append(execution.input_file(params.get("outer_surf", None)))
    if params.get("opt_voxel_subdiv_subdiv_num", None) is not None:
        cargs.extend([
            "-voxel-subdiv",
            str(params.get("opt_voxel_subdiv_subdiv_num", None))
        ])
    if params.get("opt_greedy", False):
        cargs.append("-greedy")
    if params.get("opt_thick_columns", False):
        cargs.append("-thick-columns")
    return cargs


class LabelToVolumeMappingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `LabelToVolumeMappingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume file"""


def label_to_volume_mapping_params(
    label: InputPathType,
    surface: InputPathType,
    volume_space: InputPathType,
    volume_out: str,
    opt_nearest_vertex_distance: float | None = None,
    ribbon_constrained: LabelToVolumeMappingRibbonConstrainedParameters | None = None,
) -> LabelToVolumeMappingParametersTagged:
    """
    Build parameters.
    
    Args:
        label: the input label file.
        surface: the surface to use coordinates from.
        volume_space: a volume file in the desired output volume space.
        volume_out: the output volume file.
        opt_nearest_vertex_distance: use the label from the vertex closest to\
            the voxel center: how far from the surface to map labels to voxels, in\
            mm.
        ribbon_constrained: use ribbon constrained mapping algorithm.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/label-to-volume-mapping",
        "label": label,
        "surface": surface,
        "volume_space": volume_space,
        "volume_out": volume_out,
    }
    if opt_nearest_vertex_distance is not None:
        params["opt_nearest_vertex_distance"] = opt_nearest_vertex_distance
    if ribbon_constrained is not None:
        params["ribbon_constrained"] = ribbon_constrained
    return params


def label_to_volume_mapping_cargs(
    params: LabelToVolumeMappingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-to-volume-mapping")
    cargs.append(execution.input_file(params.get("label", None)))
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("volume_space", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_nearest_vertex_distance", None) is not None:
        cargs.extend([
            "-nearest-vertex",
            str(params.get("opt_nearest_vertex_distance", None))
        ])
    if params.get("ribbon_constrained", None) is not None:
        cargs.extend(label_to_volume_mapping_ribbon_constrained_cargs(params.get("ribbon_constrained", None), execution))
    return cargs


def label_to_volume_mapping_outputs(
    params: LabelToVolumeMappingParameters,
    execution: Execution,
) -> LabelToVolumeMappingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = LabelToVolumeMappingOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def label_to_volume_mapping_execute(
    params: LabelToVolumeMappingParameters,
    runner: Runner | None = None,
) -> LabelToVolumeMappingOutputs:
    """
    label-to-volume-mapping
    
    Map label file to volume.
    
    Maps labels from a gifti label file into a volume file. You must specify
    exactly one mapping method option. The -nearest-vertex method uses the label
    from the vertex closest to the voxel center. The -ribbon-constrained method
    uses the same method as in -volume-to-surface-mapping, then uses the weights
    in reverse, with popularity logic to decide on a label to use.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelToVolumeMappingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_TO_VOLUME_MAPPING_METADATA)
    params = execution.params(params)
    cargs = label_to_volume_mapping_cargs(params, execution)
    ret = label_to_volume_mapping_outputs(params, execution)
    execution.run(cargs)
    return ret


def label_to_volume_mapping(
    label: InputPathType,
    surface: InputPathType,
    volume_space: InputPathType,
    volume_out: str,
    opt_nearest_vertex_distance: float | None = None,
    ribbon_constrained: LabelToVolumeMappingRibbonConstrainedParameters | None = None,
    runner: Runner | None = None,
) -> LabelToVolumeMappingOutputs:
    """
    label-to-volume-mapping
    
    Map label file to volume.
    
    Maps labels from a gifti label file into a volume file. You must specify
    exactly one mapping method option. The -nearest-vertex method uses the label
    from the vertex closest to the voxel center. The -ribbon-constrained method
    uses the same method as in -volume-to-surface-mapping, then uses the weights
    in reverse, with popularity logic to decide on a label to use.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label: the input label file.
        surface: the surface to use coordinates from.
        volume_space: a volume file in the desired output volume space.
        volume_out: the output volume file.
        opt_nearest_vertex_distance: use the label from the vertex closest to\
            the voxel center: how far from the surface to map labels to voxels, in\
            mm.
        ribbon_constrained: use ribbon constrained mapping algorithm.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelToVolumeMappingOutputs`).
    """
    params = label_to_volume_mapping_params(
        label=label,
        surface=surface,
        volume_space=volume_space,
        volume_out=volume_out,
        opt_nearest_vertex_distance=opt_nearest_vertex_distance,
        ribbon_constrained=ribbon_constrained,
    )
    return label_to_volume_mapping_execute(params, runner)


__all__ = [
    "LABEL_TO_VOLUME_MAPPING_METADATA",
    "LabelToVolumeMappingOutputs",
    "label_to_volume_mapping",
    "label_to_volume_mapping_execute",
    "label_to_volume_mapping_params",
    "label_to_volume_mapping_ribbon_constrained_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_LABEL_TO_SURFACE_MAPPING_METADATA = Metadata(
    id="7b2c1281854788e8dba27a0d6884b9c1e7b7708e.boutiques",
    name="volume-label-to-surface-mapping",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeLabelToSurfaceMappingRibbonConstrainedParameters = typing.TypedDict('VolumeLabelToSurfaceMappingRibbonConstrainedParameters', {
    "@type": typing.NotRequired[typing.Literal["ribbon_constrained"]],
    "inner_surf": InputPathType,
    "outer_surf": InputPathType,
    "opt_volume_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_voxel_subdiv_subdiv_num": typing.NotRequired[int | None],
    "opt_thin_columns": bool,
})
VolumeLabelToSurfaceMappingRibbonConstrainedParametersTagged = typing.TypedDict('VolumeLabelToSurfaceMappingRibbonConstrainedParametersTagged', {
    "@type": typing.Literal["ribbon_constrained"],
    "inner_surf": InputPathType,
    "outer_surf": InputPathType,
    "opt_volume_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_voxel_subdiv_subdiv_num": typing.NotRequired[int | None],
    "opt_thin_columns": bool,
})


VolumeLabelToSurfaceMappingParameters = typing.TypedDict('VolumeLabelToSurfaceMappingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-label-to-surface-mapping"]],
    "volume": InputPathType,
    "surface": InputPathType,
    "label_out": str,
    "ribbon_constrained": typing.NotRequired[VolumeLabelToSurfaceMappingRibbonConstrainedParameters | None],
    "opt_subvol_select_subvol": typing.NotRequired[str | None],
})
VolumeLabelToSurfaceMappingParametersTagged = typing.TypedDict('VolumeLabelToSurfaceMappingParametersTagged', {
    "@type": typing.Literal["workbench/volume-label-to-surface-mapping"],
    "volume": InputPathType,
    "surface": InputPathType,
    "label_out": str,
    "ribbon_constrained": typing.NotRequired[VolumeLabelToSurfaceMappingRibbonConstrainedParameters | None],
    "opt_subvol_select_subvol": typing.NotRequired[str | None],
})


def volume_label_to_surface_mapping_ribbon_constrained_params(
    inner_surf: InputPathType,
    outer_surf: InputPathType,
    opt_volume_roi_roi_volume: InputPathType | None = None,
    opt_voxel_subdiv_subdiv_num: int | None = None,
    opt_thin_columns: bool = False,
) -> VolumeLabelToSurfaceMappingRibbonConstrainedParametersTagged:
    """
    Build parameters.
    
    Args:
        inner_surf: the inner surface of the ribbon.
        outer_surf: the outer surface of the ribbon.
        opt_volume_roi_roi_volume: use a volume roi: the volume file.
        opt_voxel_subdiv_subdiv_num: voxel divisions while estimating voxel\
            weights: number of subdivisions, default 3.
        opt_thin_columns: use non-overlapping polyhedra.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "ribbon_constrained",
        "inner_surf": inner_surf,
        "outer_surf": outer_surf,
        "opt_thin_columns": opt_thin_columns,
    }
    if opt_volume_roi_roi_volume is not None:
        params["opt_volume_roi_roi_volume"] = opt_volume_roi_roi_volume
    if opt_voxel_subdiv_subdiv_num is not None:
        params["opt_voxel_subdiv_subdiv_num"] = opt_voxel_subdiv_subdiv_num
    return params


def volume_label_to_surface_mapping_ribbon_constrained_cargs(
    params: VolumeLabelToSurfaceMappingRibbonConstrainedParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-ribbon-constrained")
    cargs.append(execution.input_file(params.get("inner_surf", None)))
    cargs.append(execution.input_file(params.get("outer_surf", None)))
    if params.get("opt_volume_roi_roi_volume", None) is not None:
        cargs.extend([
            "-volume-roi",
            execution.input_file(params.get("opt_volume_roi_roi_volume", None))
        ])
    if params.get("opt_voxel_subdiv_subdiv_num", None) is not None:
        cargs.extend([
            "-voxel-subdiv",
            str(params.get("opt_voxel_subdiv_subdiv_num", None))
        ])
    if params.get("opt_thin_columns", False):
        cargs.append("-thin-columns")
    return cargs


class VolumeLabelToSurfaceMappingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeLabelToSurfaceMappingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output gifti label file"""


def volume_label_to_surface_mapping_params(
    volume: InputPathType,
    surface: InputPathType,
    label_out: str,
    ribbon_constrained: VolumeLabelToSurfaceMappingRibbonConstrainedParameters | None = None,
    opt_subvol_select_subvol: str | None = None,
) -> VolumeLabelToSurfaceMappingParametersTagged:
    """
    Build parameters.
    
    Args:
        volume: the volume to map data from.
        surface: the surface to map the data onto.
        label_out: the output gifti label file.
        ribbon_constrained: use ribbon constrained mapping algorithm.
        opt_subvol_select_subvol: select a single subvolume to map: the\
            subvolume number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-label-to-surface-mapping",
        "volume": volume,
        "surface": surface,
        "label_out": label_out,
    }
    if ribbon_constrained is not None:
        params["ribbon_constrained"] = ribbon_constrained
    if opt_subvol_select_subvol is not None:
        params["opt_subvol_select_subvol"] = opt_subvol_select_subvol
    return params


def volume_label_to_surface_mapping_cargs(
    params: VolumeLabelToSurfaceMappingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-label-to-surface-mapping")
    cargs.append(execution.input_file(params.get("volume", None)))
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("label_out", None))
    if params.get("ribbon_constrained", None) is not None:
        cargs.extend(volume_label_to_surface_mapping_ribbon_constrained_cargs(params.get("ribbon_constrained", None), execution))
    if params.get("opt_subvol_select_subvol", None) is not None:
        cargs.extend([
            "-subvol-select",
            params.get("opt_subvol_select_subvol", None)
        ])
    return cargs


def volume_label_to_surface_mapping_outputs(
    params: VolumeLabelToSurfaceMappingParameters,
    execution: Execution,
) -> VolumeLabelToSurfaceMappingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeLabelToSurfaceMappingOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(params.get("label_out", None)),
    )
    return ret


def volume_label_to_surface_mapping_execute(
    params: VolumeLabelToSurfaceMappingParameters,
    runner: Runner | None = None,
) -> VolumeLabelToSurfaceMappingOutputs:
    """
    volume-label-to-surface-mapping
    
    Map a label volume to a surface label file.
    
    Map label volume data to a surface. If -ribbon-constrained is not specified,
    uses the enclosing voxel method. The ribbon mapping method constructs a
    polyhedron from the vertex's neighbors on each surface, and estimates the
    amount of this polyhedron's volume that falls inside any nearby voxels, to
    use as the weights for a popularity comparison. If -thin-columns is
    specified, the polyhedron uses the edge midpoints and triangle centroids, so
    that neighboring vertices do not have overlapping polyhedra. This may
    require increasing -voxel-subdiv to get enough samples in each voxel to
    reliably land inside these smaller polyhedra. The volume ROI is useful to
    exclude partial volume effects of voxels the surfaces pass through, and will
    cause the mapping to ignore voxels that don't have a positive value in the
    mask. The subdivision number specifies how it approximates the amount of the
    volume the polyhedron intersects, by splitting each voxel into NxNxN pieces,
    and checking whether the center of each piece is inside the polyhedron. If
    you have very large voxels, consider increasing this if you get unexpected
    unlabeled vertices in your output.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelToSurfaceMappingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_LABEL_TO_SURFACE_MAPPING_METADATA)
    params = execution.params(params)
    cargs = volume_label_to_surface_mapping_cargs(params, execution)
    ret = volume_label_to_surface_mapping_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_label_to_surface_mapping(
    volume: InputPathType,
    surface: InputPathType,
    label_out: str,
    ribbon_constrained: VolumeLabelToSurfaceMappingRibbonConstrainedParameters | None = None,
    opt_subvol_select_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeLabelToSurfaceMappingOutputs:
    """
    volume-label-to-surface-mapping
    
    Map a label volume to a surface label file.
    
    Map label volume data to a surface. If -ribbon-constrained is not specified,
    uses the enclosing voxel method. The ribbon mapping method constructs a
    polyhedron from the vertex's neighbors on each surface, and estimates the
    amount of this polyhedron's volume that falls inside any nearby voxels, to
    use as the weights for a popularity comparison. If -thin-columns is
    specified, the polyhedron uses the edge midpoints and triangle centroids, so
    that neighboring vertices do not have overlapping polyhedra. This may
    require increasing -voxel-subdiv to get enough samples in each voxel to
    reliably land inside these smaller polyhedra. The volume ROI is useful to
    exclude partial volume effects of voxels the surfaces pass through, and will
    cause the mapping to ignore voxels that don't have a positive value in the
    mask. The subdivision number specifies how it approximates the amount of the
    volume the polyhedron intersects, by splitting each voxel into NxNxN pieces,
    and checking whether the center of each piece is inside the polyhedron. If
    you have very large voxels, consider increasing this if you get unexpected
    unlabeled vertices in your output.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the volume to map data from.
        surface: the surface to map the data onto.
        label_out: the output gifti label file.
        ribbon_constrained: use ribbon constrained mapping algorithm.
        opt_subvol_select_subvol: select a single subvolume to map: the\
            subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelToSurfaceMappingOutputs`).
    """
    params = volume_label_to_surface_mapping_params(
        volume=volume,
        surface=surface,
        label_out=label_out,
        ribbon_constrained=ribbon_constrained,
        opt_subvol_select_subvol=opt_subvol_select_subvol,
    )
    return volume_label_to_surface_mapping_execute(params, runner)


__all__ = [
    "VOLUME_LABEL_TO_SURFACE_MAPPING_METADATA",
    "VolumeLabelToSurfaceMappingOutputs",
    "volume_label_to_surface_mapping",
    "volume_label_to_surface_mapping_execute",
    "volume_label_to_surface_mapping_params",
    "volume_label_to_surface_mapping_ribbon_constrained_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ZIP_SPEC_FILE_METADATA = Metadata(
    id="5bc4445351c0f8efed67b439599fb8b5b4042e41.boutiques",
    name="zip-spec-file",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


ZipSpecFileParameters = typing.TypedDict('ZipSpecFileParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/zip-spec-file"]],
    "spec_file": str,
    "extract_folder": str,
    "zip_file": str,
    "opt_base_dir_directory": typing.NotRequired[str | None],
    "opt_skip_missing": bool,
})
ZipSpecFileParametersTagged = typing.TypedDict('ZipSpecFileParametersTagged', {
    "@type": typing.Literal["workbench/zip-spec-file"],
    "spec_file": str,
    "extract_folder": str,
    "zip_file": str,
    "opt_base_dir_directory": typing.NotRequired[str | None],
    "opt_skip_missing": bool,
})


class ZipSpecFileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ZipSpecFileParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def zip_spec_file_params(
    spec_file: str,
    extract_folder: str,
    zip_file: str,
    opt_base_dir_directory: str | None = None,
    opt_skip_missing: bool = False,
) -> ZipSpecFileParametersTagged:
    """
    Build parameters.
    
    Args:
        spec_file: the specification file to add to zip file.
        extract_folder: the name of the folder created when the zip file is\
            unzipped.
        zip_file: out - the zip file that will be created.
        opt_base_dir_directory: specify a directory that all data files are\
            somewhere within, this will become the root of the zipfile's directory\
            structure: the directory.
        opt_skip_missing: any missing files will generate only warnings, and\
            the zip file will be created anyway.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/zip-spec-file",
        "spec_file": spec_file,
        "extract_folder": extract_folder,
        "zip_file": zip_file,
        "opt_skip_missing": opt_skip_missing,
    }
    if opt_base_dir_directory is not None:
        params["opt_base_dir_directory"] = opt_base_dir_directory
    return params


def zip_spec_file_cargs(
    params: ZipSpecFileParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-zip-spec-file")
    cargs.append(params.get("spec_file", None))
    cargs.append(params.get("extract_folder", None))
    cargs.append(params.get("zip_file", None))
    if params.get("opt_base_dir_directory", None) is not None:
        cargs.extend([
            "-base-dir",
            params.get("opt_base_dir_directory", None)
        ])
    if params.get("opt_skip_missing", False):
        cargs.append("-skip-missing")
    return cargs


def zip_spec_file_outputs(
    params: ZipSpecFileParameters,
    execution: Execution,
) -> ZipSpecFileOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ZipSpecFileOutputs(
        root=execution.output_file("."),
    )
    return ret


def zip_spec_file_execute(
    params: ZipSpecFileParameters,
    runner: Runner | None = None,
) -> ZipSpecFileOutputs:
    """
    zip-spec-file
    
    Zip a spec file and its data files.
    
    If zip-file already exists, it will be overwritten. If -base-dir is not
    specified, the directory containing the spec file is used for the base
    directory. The spec file must contain only relative paths, and no data files
    may be outside the base directory. Scene files inside spec files are not
    checked for what files they reference, ensure that all data files referenced
    by the scene files are also referenced by the spec file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZipSpecFileOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ZIP_SPEC_FILE_METADATA)
    params = execution.params(params)
    cargs = zip_spec_file_cargs(params, execution)
    ret = zip_spec_file_outputs(params, execution)
    execution.run(cargs)
    return ret


def zip_spec_file(
    spec_file: str,
    extract_folder: str,
    zip_file: str,
    opt_base_dir_directory: str | None = None,
    opt_skip_missing: bool = False,
    runner: Runner | None = None,
) -> ZipSpecFileOutputs:
    """
    zip-spec-file
    
    Zip a spec file and its data files.
    
    If zip-file already exists, it will be overwritten. If -base-dir is not
    specified, the directory containing the spec file is used for the base
    directory. The spec file must contain only relative paths, and no data files
    may be outside the base directory. Scene files inside spec files are not
    checked for what files they reference, ensure that all data files referenced
    by the scene files are also referenced by the spec file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        spec_file: the specification file to add to zip file.
        extract_folder: the name of the folder created when the zip file is\
            unzipped.
        zip_file: out - the zip file that will be created.
        opt_base_dir_directory: specify a directory that all data files are\
            somewhere within, this will become the root of the zipfile's directory\
            structure: the directory.
        opt_skip_missing: any missing files will generate only warnings, and\
            the zip file will be created anyway.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZipSpecFileOutputs`).
    """
    params = zip_spec_file_params(
        spec_file=spec_file,
        extract_folder=extract_folder,
        zip_file=zip_file,
        opt_base_dir_directory=opt_base_dir_directory,
        opt_skip_missing=opt_skip_missing,
    )
    return zip_spec_file_execute(params, runner)


__all__ = [
    "ZIP_SPEC_FILE_METADATA",
    "ZipSpecFileOutputs",
    "zip_spec_file",
    "zip_spec_file_execute",
    "zip_spec_file_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_FILL_HOLES_METADATA = Metadata(
    id="b215833557d957fc6f98c6569e125d6daf82e9b8.boutiques",
    name="volume-fill-holes",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeFillHolesParameters = typing.TypedDict('VolumeFillHolesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-fill-holes"]],
    "volume_in": InputPathType,
    "volume_out": str,
})
VolumeFillHolesParametersTagged = typing.TypedDict('VolumeFillHolesParametersTagged', {
    "@type": typing.Literal["workbench/volume-fill-holes"],
    "volume_in": InputPathType,
    "volume_out": str,
})


class VolumeFillHolesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeFillHolesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output ROI volume"""


def volume_fill_holes_params(
    volume_in: InputPathType,
    volume_out: str,
) -> VolumeFillHolesParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the input ROI volume.
        volume_out: the output ROI volume.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-fill-holes",
        "volume_in": volume_in,
        "volume_out": volume_out,
    }
    return params


def volume_fill_holes_cargs(
    params: VolumeFillHolesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-fill-holes")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(params.get("volume_out", None))
    return cargs


def volume_fill_holes_outputs(
    params: VolumeFillHolesParameters,
    execution: Execution,
) -> VolumeFillHolesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeFillHolesOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_fill_holes_execute(
    params: VolumeFillHolesParameters,
    runner: Runner | None = None,
) -> VolumeFillHolesOutputs:
    """
    volume-fill-holes
    
    Fill holes in an roi volume.
    
    Finds all face-connected parts that are not included in the ROI, and fills
    all but the largest one with ones.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeFillHolesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_FILL_HOLES_METADATA)
    params = execution.params(params)
    cargs = volume_fill_holes_cargs(params, execution)
    ret = volume_fill_holes_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_fill_holes(
    volume_in: InputPathType,
    volume_out: str,
    runner: Runner | None = None,
) -> VolumeFillHolesOutputs:
    """
    volume-fill-holes
    
    Fill holes in an roi volume.
    
    Finds all face-connected parts that are not included in the ROI, and fills
    all but the largest one with ones.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input ROI volume.
        volume_out: the output ROI volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeFillHolesOutputs`).
    """
    params = volume_fill_holes_params(
        volume_in=volume_in,
        volume_out=volume_out,
    )
    return volume_fill_holes_execute(params, runner)


__all__ = [
    "VOLUME_FILL_HOLES_METADATA",
    "VolumeFillHolesOutputs",
    "volume_fill_holes",
    "volume_fill_holes_execute",
    "volume_fill_holes_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SPEC_FILE_RELOCATE_METADATA = Metadata(
    id="749f2233af5a8f3e4bd24c29117982578dc8bf47.boutiques",
    name="spec-file-relocate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SpecFileRelocateParameters = typing.TypedDict('SpecFileRelocateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/spec-file-relocate"]],
    "input_spec": str,
    "output_spec": str,
})
SpecFileRelocateParametersTagged = typing.TypedDict('SpecFileRelocateParametersTagged', {
    "@type": typing.Literal["workbench/spec-file-relocate"],
    "input_spec": str,
    "output_spec": str,
})


class SpecFileRelocateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SpecFileRelocateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def spec_file_relocate_params(
    input_spec: str,
    output_spec: str,
) -> SpecFileRelocateParametersTagged:
    """
    Build parameters.
    
    Args:
        input_spec: the spec file to use.
        output_spec: output - the new spec file to create.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/spec-file-relocate",
        "input_spec": input_spec,
        "output_spec": output_spec,
    }
    return params


def spec_file_relocate_cargs(
    params: SpecFileRelocateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-spec-file-relocate")
    cargs.append(params.get("input_spec", None))
    cargs.append(params.get("output_spec", None))
    return cargs


def spec_file_relocate_outputs(
    params: SpecFileRelocateParameters,
    execution: Execution,
) -> SpecFileRelocateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SpecFileRelocateOutputs(
        root=execution.output_file("."),
    )
    return ret


def spec_file_relocate_execute(
    params: SpecFileRelocateParameters,
    runner: Runner | None = None,
) -> SpecFileRelocateOutputs:
    """
    spec-file-relocate
    
    Recreate spec file in new location.
    
    Spec files contain internal relative paths, such that moving or copying a
    spec file will cause it to lose track of the files it refers to. This
    command makes a modified copy of the spec file, changing the relative paths
    to refer to the new relative locations of the files.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpecFileRelocateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPEC_FILE_RELOCATE_METADATA)
    params = execution.params(params)
    cargs = spec_file_relocate_cargs(params, execution)
    ret = spec_file_relocate_outputs(params, execution)
    execution.run(cargs)
    return ret


def spec_file_relocate(
    input_spec: str,
    output_spec: str,
    runner: Runner | None = None,
) -> SpecFileRelocateOutputs:
    """
    spec-file-relocate
    
    Recreate spec file in new location.
    
    Spec files contain internal relative paths, such that moving or copying a
    spec file will cause it to lose track of the files it refers to. This
    command makes a modified copy of the spec file, changing the relative paths
    to refer to the new relative locations of the files.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_spec: the spec file to use.
        output_spec: output - the new spec file to create.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpecFileRelocateOutputs`).
    """
    params = spec_file_relocate_params(
        input_spec=input_spec,
        output_spec=output_spec,
    )
    return spec_file_relocate_execute(params, runner)


__all__ = [
    "SPEC_FILE_RELOCATE_METADATA",
    "SpecFileRelocateOutputs",
    "spec_file_relocate",
    "spec_file_relocate_execute",
    "spec_file_relocate_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BORDER_LENGTH_METADATA = Metadata(
    id="53685982ac0f6c80b96345649dc3d3bb8389bb5b.boutiques",
    name="border-length",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


BorderLengthParameters = typing.TypedDict('BorderLengthParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/border-length"]],
    "border": InputPathType,
    "surface": InputPathType,
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_separate_pieces": bool,
    "opt_hide_border_name": bool,
})
BorderLengthParametersTagged = typing.TypedDict('BorderLengthParametersTagged', {
    "@type": typing.Literal["workbench/border-length"],
    "border": InputPathType,
    "surface": InputPathType,
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_separate_pieces": bool,
    "opt_hide_border_name": bool,
})


class BorderLengthOutputs(typing.NamedTuple):
    """
    Output object returned when calling `BorderLengthParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def border_length_params(
    border: InputPathType,
    surface: InputPathType,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_separate_pieces: bool = False,
    opt_hide_border_name: bool = False,
) -> BorderLengthParametersTagged:
    """
    Build parameters.
    
    Args:
        border: the input border file.
        surface: the surface to measure the borders on.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_separate_pieces: report lengths for multi-part borders as separate\
            numbers.
        opt_hide_border_name: don't print border name before each output.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/border-length",
        "border": border,
        "surface": surface,
        "opt_separate_pieces": opt_separate_pieces,
        "opt_hide_border_name": opt_hide_border_name,
    }
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def border_length_cargs(
    params: BorderLengthParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-length")
    cargs.append(execution.input_file(params.get("border", None)))
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    if params.get("opt_separate_pieces", False):
        cargs.append("-separate-pieces")
    if params.get("opt_hide_border_name", False):
        cargs.append("-hide-border-name")
    return cargs


def border_length_outputs(
    params: BorderLengthParameters,
    execution: Execution,
) -> BorderLengthOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BorderLengthOutputs(
        root=execution.output_file("."),
    )
    return ret


def border_length_execute(
    params: BorderLengthParameters,
    runner: Runner | None = None,
) -> BorderLengthOutputs:
    """
    border-length
    
    Report length of borders.
    
    For each border, print its length along the surface, in mm. If a border has
    multiple parts, their lengths are summed before printing, unless
    -separate-pieces is specified.
    
    The -corrected-areas option is intended for when the length is not
    meaningfully measurable on individual surfaces, it is only an approximate
    correction for the reduction in structure of a group average surface.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderLengthOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_LENGTH_METADATA)
    params = execution.params(params)
    cargs = border_length_cargs(params, execution)
    ret = border_length_outputs(params, execution)
    execution.run(cargs)
    return ret


def border_length(
    border: InputPathType,
    surface: InputPathType,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_separate_pieces: bool = False,
    opt_hide_border_name: bool = False,
    runner: Runner | None = None,
) -> BorderLengthOutputs:
    """
    border-length
    
    Report length of borders.
    
    For each border, print its length along the surface, in mm. If a border has
    multiple parts, their lengths are summed before printing, unless
    -separate-pieces is specified.
    
    The -corrected-areas option is intended for when the length is not
    meaningfully measurable on individual surfaces, it is only an approximate
    correction for the reduction in structure of a group average surface.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        border: the input border file.
        surface: the surface to measure the borders on.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_separate_pieces: report lengths for multi-part borders as separate\
            numbers.
        opt_hide_border_name: don't print border name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderLengthOutputs`).
    """
    params = border_length_params(
        border=border,
        surface=surface,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
        opt_separate_pieces=opt_separate_pieces,
        opt_hide_border_name=opt_hide_border_name,
    )
    return border_length_execute(params, runner)


__all__ = [
    "BORDER_LENGTH_METADATA",
    "BorderLengthOutputs",
    "border_length",
    "border_length_execute",
    "border_length_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_NORMALS_METADATA = Metadata(
    id="a04e63a81424932a907bb5d57ff1d5439a7a29aa.boutiques",
    name="surface-normals",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceNormalsParameters = typing.TypedDict('SurfaceNormalsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-normals"]],
    "surface": InputPathType,
    "metric_out": str,
})
SurfaceNormalsParametersTagged = typing.TypedDict('SurfaceNormalsParametersTagged', {
    "@type": typing.Literal["workbench/surface-normals"],
    "surface": InputPathType,
    "metric_out": str,
})


class SurfaceNormalsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceNormalsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the normal vectors"""


def surface_normals_params(
    surface: InputPathType,
    metric_out: str,
) -> SurfaceNormalsParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to output the normals of.
        metric_out: the normal vectors.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-normals",
        "surface": surface,
        "metric_out": metric_out,
    }
    return params


def surface_normals_cargs(
    params: SurfaceNormalsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-normals")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("metric_out", None))
    return cargs


def surface_normals_outputs(
    params: SurfaceNormalsParameters,
    execution: Execution,
) -> SurfaceNormalsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceNormalsOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def surface_normals_execute(
    params: SurfaceNormalsParameters,
    runner: Runner | None = None,
) -> SurfaceNormalsOutputs:
    """
    surface-normals
    
    Output vertex normals as metric file.
    
    Computes the normal vectors of the surface file, and outputs them as a 3
    column metric file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceNormalsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_NORMALS_METADATA)
    params = execution.params(params)
    cargs = surface_normals_cargs(params, execution)
    ret = surface_normals_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_normals(
    surface: InputPathType,
    metric_out: str,
    runner: Runner | None = None,
) -> SurfaceNormalsOutputs:
    """
    surface-normals
    
    Output vertex normals as metric file.
    
    Computes the normal vectors of the surface file, and outputs them as a 3
    column metric file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to output the normals of.
        metric_out: the normal vectors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceNormalsOutputs`).
    """
    params = surface_normals_params(
        surface=surface,
        metric_out=metric_out,
    )
    return surface_normals_execute(params, runner)


__all__ = [
    "SURFACE_NORMALS_METADATA",
    "SurfaceNormalsOutputs",
    "surface_normals",
    "surface_normals_execute",
    "surface_normals_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

FOCI_RESAMPLE_METADATA = Metadata(
    id="a6b7818d908aa723048260f636255843659503e2.boutiques",
    name="foci-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


FociResampleLeftSurfacesParameters = typing.TypedDict('FociResampleLeftSurfacesParameters', {
    "@type": typing.NotRequired[typing.Literal["left_surfaces"]],
    "current_surf": InputPathType,
    "new_surf": InputPathType,
})
FociResampleLeftSurfacesParametersTagged = typing.TypedDict('FociResampleLeftSurfacesParametersTagged', {
    "@type": typing.Literal["left_surfaces"],
    "current_surf": InputPathType,
    "new_surf": InputPathType,
})


FociResampleRightSurfacesParameters = typing.TypedDict('FociResampleRightSurfacesParameters', {
    "@type": typing.NotRequired[typing.Literal["right_surfaces"]],
    "current_surf": InputPathType,
    "new_surf": InputPathType,
})
FociResampleRightSurfacesParametersTagged = typing.TypedDict('FociResampleRightSurfacesParametersTagged', {
    "@type": typing.Literal["right_surfaces"],
    "current_surf": InputPathType,
    "new_surf": InputPathType,
})


FociResampleCerebellumSurfacesParameters = typing.TypedDict('FociResampleCerebellumSurfacesParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_surfaces"]],
    "current_surf": InputPathType,
    "new_surf": InputPathType,
})
FociResampleCerebellumSurfacesParametersTagged = typing.TypedDict('FociResampleCerebellumSurfacesParametersTagged', {
    "@type": typing.Literal["cerebellum_surfaces"],
    "current_surf": InputPathType,
    "new_surf": InputPathType,
})


FociResampleParameters = typing.TypedDict('FociResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/foci-resample"]],
    "foci_in": InputPathType,
    "foci_out": str,
    "left_surfaces": typing.NotRequired[FociResampleLeftSurfacesParameters | None],
    "right_surfaces": typing.NotRequired[FociResampleRightSurfacesParameters | None],
    "cerebellum_surfaces": typing.NotRequired[FociResampleCerebellumSurfacesParameters | None],
    "opt_discard_distance_from_surface": bool,
    "opt_restore_xyz": bool,
})
FociResampleParametersTagged = typing.TypedDict('FociResampleParametersTagged', {
    "@type": typing.Literal["workbench/foci-resample"],
    "foci_in": InputPathType,
    "foci_out": str,
    "left_surfaces": typing.NotRequired[FociResampleLeftSurfacesParameters | None],
    "right_surfaces": typing.NotRequired[FociResampleRightSurfacesParameters | None],
    "cerebellum_surfaces": typing.NotRequired[FociResampleCerebellumSurfacesParameters | None],
    "opt_discard_distance_from_surface": bool,
    "opt_restore_xyz": bool,
})


def foci_resample_left_surfaces_params(
    current_surf: InputPathType,
    new_surf: InputPathType,
) -> FociResampleLeftSurfacesParametersTagged:
    """
    Build parameters.
    
    Args:
        current_surf: the surface the foci are currently projected on.
        new_surf: the surface to project the foci onto.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_surfaces",
        "current_surf": current_surf,
        "new_surf": new_surf,
    }
    return params


def foci_resample_left_surfaces_cargs(
    params: FociResampleLeftSurfacesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-surfaces")
    cargs.append(execution.input_file(params.get("current_surf", None)))
    cargs.append(execution.input_file(params.get("new_surf", None)))
    return cargs


def foci_resample_right_surfaces_params(
    current_surf: InputPathType,
    new_surf: InputPathType,
) -> FociResampleRightSurfacesParametersTagged:
    """
    Build parameters.
    
    Args:
        current_surf: the surface the foci are currently projected on.
        new_surf: the surface to project the foci onto.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_surfaces",
        "current_surf": current_surf,
        "new_surf": new_surf,
    }
    return params


def foci_resample_right_surfaces_cargs(
    params: FociResampleRightSurfacesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-surfaces")
    cargs.append(execution.input_file(params.get("current_surf", None)))
    cargs.append(execution.input_file(params.get("new_surf", None)))
    return cargs


def foci_resample_cerebellum_surfaces_params(
    current_surf: InputPathType,
    new_surf: InputPathType,
) -> FociResampleCerebellumSurfacesParametersTagged:
    """
    Build parameters.
    
    Args:
        current_surf: the surface the foci are currently projected on.
        new_surf: the surface to project the foci onto.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_surfaces",
        "current_surf": current_surf,
        "new_surf": new_surf,
    }
    return params


def foci_resample_cerebellum_surfaces_cargs(
    params: FociResampleCerebellumSurfacesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-surfaces")
    cargs.append(execution.input_file(params.get("current_surf", None)))
    cargs.append(execution.input_file(params.get("new_surf", None)))
    return cargs


class FociResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `FociResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    foci_out: OutputPathType
    """the output foci file"""


def foci_resample_params(
    foci_in: InputPathType,
    foci_out: str,
    left_surfaces: FociResampleLeftSurfacesParameters | None = None,
    right_surfaces: FociResampleRightSurfacesParameters | None = None,
    cerebellum_surfaces: FociResampleCerebellumSurfacesParameters | None = None,
    opt_discard_distance_from_surface: bool = False,
    opt_restore_xyz: bool = False,
) -> FociResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        foci_in: the input foci file.
        foci_out: the output foci file.
        left_surfaces: the left surfaces for resampling.
        right_surfaces: the right surfaces for resampling.
        cerebellum_surfaces: the cerebellum surfaces for resampling.
        opt_discard_distance_from_surface: ignore the distance the foci are\
            above or below the current surface.
        opt_restore_xyz: put the original xyz coordinates into the foci, rather\
            than the coordinates obtained from unprojection.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/foci-resample",
        "foci_in": foci_in,
        "foci_out": foci_out,
        "opt_discard_distance_from_surface": opt_discard_distance_from_surface,
        "opt_restore_xyz": opt_restore_xyz,
    }
    if left_surfaces is not None:
        params["left_surfaces"] = left_surfaces
    if right_surfaces is not None:
        params["right_surfaces"] = right_surfaces
    if cerebellum_surfaces is not None:
        params["cerebellum_surfaces"] = cerebellum_surfaces
    return params


def foci_resample_cargs(
    params: FociResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-foci-resample")
    cargs.append(execution.input_file(params.get("foci_in", None)))
    cargs.append(params.get("foci_out", None))
    if params.get("left_surfaces", None) is not None:
        cargs.extend(foci_resample_left_surfaces_cargs(params.get("left_surfaces", None), execution))
    if params.get("right_surfaces", None) is not None:
        cargs.extend(foci_resample_right_surfaces_cargs(params.get("right_surfaces", None), execution))
    if params.get("cerebellum_surfaces", None) is not None:
        cargs.extend(foci_resample_cerebellum_surfaces_cargs(params.get("cerebellum_surfaces", None), execution))
    if params.get("opt_discard_distance_from_surface", False):
        cargs.append("-discard-distance-from-surface")
    if params.get("opt_restore_xyz", False):
        cargs.append("-restore-xyz")
    return cargs


def foci_resample_outputs(
    params: FociResampleParameters,
    execution: Execution,
) -> FociResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = FociResampleOutputs(
        root=execution.output_file("."),
        foci_out=execution.output_file(params.get("foci_out", None)),
    )
    return ret


def foci_resample_execute(
    params: FociResampleParameters,
    runner: Runner | None = None,
) -> FociResampleOutputs:
    """
    foci-resample
    
    Project foci to a different surface.
    
    Unprojects foci from the <current-surf> for the structure, then projects
    them to <new-surf>. If the foci have meaningful distances above or below the
    surface, use anatomical surfaces. If the foci should be on the surface, use
    registered spheres and the options -discard-distance-from-surface and
    -restore-xyz.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FOCI_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = foci_resample_cargs(params, execution)
    ret = foci_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def foci_resample(
    foci_in: InputPathType,
    foci_out: str,
    left_surfaces: FociResampleLeftSurfacesParameters | None = None,
    right_surfaces: FociResampleRightSurfacesParameters | None = None,
    cerebellum_surfaces: FociResampleCerebellumSurfacesParameters | None = None,
    opt_discard_distance_from_surface: bool = False,
    opt_restore_xyz: bool = False,
    runner: Runner | None = None,
) -> FociResampleOutputs:
    """
    foci-resample
    
    Project foci to a different surface.
    
    Unprojects foci from the <current-surf> for the structure, then projects
    them to <new-surf>. If the foci have meaningful distances above or below the
    surface, use anatomical surfaces. If the foci should be on the surface, use
    registered spheres and the options -discard-distance-from-surface and
    -restore-xyz.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        foci_in: the input foci file.
        foci_out: the output foci file.
        left_surfaces: the left surfaces for resampling.
        right_surfaces: the right surfaces for resampling.
        cerebellum_surfaces: the cerebellum surfaces for resampling.
        opt_discard_distance_from_surface: ignore the distance the foci are\
            above or below the current surface.
        opt_restore_xyz: put the original xyz coordinates into the foci, rather\
            than the coordinates obtained from unprojection.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociResampleOutputs`).
    """
    params = foci_resample_params(
        foci_in=foci_in,
        foci_out=foci_out,
        left_surfaces=left_surfaces,
        right_surfaces=right_surfaces,
        cerebellum_surfaces=cerebellum_surfaces,
        opt_discard_distance_from_surface=opt_discard_distance_from_surface,
        opt_restore_xyz=opt_restore_xyz,
    )
    return foci_resample_execute(params, runner)


__all__ = [
    "FOCI_RESAMPLE_METADATA",
    "FociResampleOutputs",
    "foci_resample",
    "foci_resample_cerebellum_surfaces_params",
    "foci_resample_execute",
    "foci_resample_left_surfaces_params",
    "foci_resample_params",
    "foci_resample_right_surfaces_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_MASK_METADATA = Metadata(
    id="63170647bafcd7131594caf978d3951bd09b8dc0.boutiques",
    name="metric-mask",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricMaskParameters = typing.TypedDict('MetricMaskParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-mask"]],
    "metric": InputPathType,
    "mask": InputPathType,
    "metric_out": str,
    "opt_column_column": typing.NotRequired[str | None],
})
MetricMaskParametersTagged = typing.TypedDict('MetricMaskParametersTagged', {
    "@type": typing.Literal["workbench/metric-mask"],
    "metric": InputPathType,
    "mask": InputPathType,
    "metric_out": str,
    "opt_column_column": typing.NotRequired[str | None],
})


class MetricMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricMaskParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_mask_params(
    metric: InputPathType,
    mask: InputPathType,
    metric_out: str,
    opt_column_column: str | None = None,
) -> MetricMaskParametersTagged:
    """
    Build parameters.
    
    Args:
        metric: the input metric.
        mask: the mask metric.
        metric_out: the output metric.
        opt_column_column: select a single column: the column number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-mask",
        "metric": metric,
        "mask": mask,
        "metric_out": metric_out,
    }
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    return params


def metric_mask_cargs(
    params: MetricMaskParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-mask")
    cargs.append(execution.input_file(params.get("metric", None)))
    cargs.append(execution.input_file(params.get("mask", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    return cargs


def metric_mask_outputs(
    params: MetricMaskParameters,
    execution: Execution,
) -> MetricMaskOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricMaskOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_mask_execute(
    params: MetricMaskParameters,
    runner: Runner | None = None,
) -> MetricMaskOutputs:
    """
    metric-mask
    
    Mask a metric file.
    
    By default, the output metric is a copy of the input metric, but with zeros
    wherever the mask metric is zero or negative. if -column is specified, the
    output contains only one column, the masked version of the specified input
    column.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_MASK_METADATA)
    params = execution.params(params)
    cargs = metric_mask_cargs(params, execution)
    ret = metric_mask_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_mask(
    metric: InputPathType,
    mask: InputPathType,
    metric_out: str,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> MetricMaskOutputs:
    """
    metric-mask
    
    Mask a metric file.
    
    By default, the output metric is a copy of the input metric, but with zeros
    wherever the mask metric is zero or negative. if -column is specified, the
    output contains only one column, the masked version of the specified input
    column.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric: the input metric.
        mask: the mask metric.
        metric_out: the output metric.
        opt_column_column: select a single column: the column number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricMaskOutputs`).
    """
    params = metric_mask_params(
        metric=metric,
        mask=mask,
        metric_out=metric_out,
        opt_column_column=opt_column_column,
    )
    return metric_mask_execute(params, runner)


__all__ = [
    "METRIC_MASK_METADATA",
    "MetricMaskOutputs",
    "metric_mask",
    "metric_mask_execute",
    "metric_mask_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_COPY_EXTENSIONS_METADATA = Metadata(
    id="1105ee211cb759964c59c0d9326f8fd29db4b9a2.boutiques",
    name="volume-copy-extensions",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeCopyExtensionsParameters = typing.TypedDict('VolumeCopyExtensionsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-copy-extensions"]],
    "data_volume": InputPathType,
    "extension_volume": InputPathType,
    "volume_out": str,
    "opt_drop_unknown": bool,
})
VolumeCopyExtensionsParametersTagged = typing.TypedDict('VolumeCopyExtensionsParametersTagged', {
    "@type": typing.Literal["workbench/volume-copy-extensions"],
    "data_volume": InputPathType,
    "extension_volume": InputPathType,
    "volume_out": str,
    "opt_drop_unknown": bool,
})


class VolumeCopyExtensionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeCopyExtensionsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_copy_extensions_params(
    data_volume: InputPathType,
    extension_volume: InputPathType,
    volume_out: str,
    opt_drop_unknown: bool = False,
) -> VolumeCopyExtensionsParametersTagged:
    """
    Build parameters.
    
    Args:
        data_volume: the volume file containing the voxel data to use.
        extension_volume: the volume file containing the extensions to use.
        volume_out: the output volume.
        opt_drop_unknown: don't copy extensions that workbench doesn't\
            understand.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-copy-extensions",
        "data_volume": data_volume,
        "extension_volume": extension_volume,
        "volume_out": volume_out,
        "opt_drop_unknown": opt_drop_unknown,
    }
    return params


def volume_copy_extensions_cargs(
    params: VolumeCopyExtensionsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-copy-extensions")
    cargs.append(execution.input_file(params.get("data_volume", None)))
    cargs.append(execution.input_file(params.get("extension_volume", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_drop_unknown", False):
        cargs.append("-drop-unknown")
    return cargs


def volume_copy_extensions_outputs(
    params: VolumeCopyExtensionsParameters,
    execution: Execution,
) -> VolumeCopyExtensionsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeCopyExtensionsOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_copy_extensions_execute(
    params: VolumeCopyExtensionsParameters,
    runner: Runner | None = None,
) -> VolumeCopyExtensionsOutputs:
    """
    volume-copy-extensions
    
    Copy extended data to another volume file.
    
    This command copies the information in a volume file that isn't a critical
    part of the standard header or data matrix, e.g. map names, palette
    settings, label tables. If -drop-unknown is not specified, it also copies
    similar kinds of information set by other software.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCopyExtensionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_COPY_EXTENSIONS_METADATA)
    params = execution.params(params)
    cargs = volume_copy_extensions_cargs(params, execution)
    ret = volume_copy_extensions_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_copy_extensions(
    data_volume: InputPathType,
    extension_volume: InputPathType,
    volume_out: str,
    opt_drop_unknown: bool = False,
    runner: Runner | None = None,
) -> VolumeCopyExtensionsOutputs:
    """
    volume-copy-extensions
    
    Copy extended data to another volume file.
    
    This command copies the information in a volume file that isn't a critical
    part of the standard header or data matrix, e.g. map names, palette
    settings, label tables. If -drop-unknown is not specified, it also copies
    similar kinds of information set by other software.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_volume: the volume file containing the voxel data to use.
        extension_volume: the volume file containing the extensions to use.
        volume_out: the output volume.
        opt_drop_unknown: don't copy extensions that workbench doesn't\
            understand.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCopyExtensionsOutputs`).
    """
    params = volume_copy_extensions_params(
        data_volume=data_volume,
        extension_volume=extension_volume,
        volume_out=volume_out,
        opt_drop_unknown=opt_drop_unknown,
    )
    return volume_copy_extensions_execute(params, runner)


__all__ = [
    "VOLUME_COPY_EXTENSIONS_METADATA",
    "VolumeCopyExtensionsOutputs",
    "volume_copy_extensions",
    "volume_copy_extensions_execute",
    "volume_copy_extensions_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_EXTREMA_METADATA = Metadata(
    id="30b679ce9711d1251e93a3a78a855b94ac05e5d6.boutiques",
    name="cifti-extrema",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiExtremaThresholdParameters = typing.TypedDict('CiftiExtremaThresholdParameters', {
    "@type": typing.NotRequired[typing.Literal["threshold"]],
    "low": float,
    "high": float,
})
CiftiExtremaThresholdParametersTagged = typing.TypedDict('CiftiExtremaThresholdParametersTagged', {
    "@type": typing.Literal["threshold"],
    "low": float,
    "high": float,
})


CiftiExtremaParameters = typing.TypedDict('CiftiExtremaParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-extrema"]],
    "cifti": InputPathType,
    "surface_distance": float,
    "volume_distance": float,
    "direction": str,
    "cifti_out": str,
    "opt_left_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_right_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_surface_presmooth_surface_kernel": typing.NotRequired[float | None],
    "opt_volume_presmooth_volume_kernel": typing.NotRequired[float | None],
    "opt_presmooth_fwhm": bool,
    "threshold": typing.NotRequired[CiftiExtremaThresholdParameters | None],
    "opt_merged_volume": bool,
    "opt_sum_maps": bool,
    "opt_consolidate_mode": bool,
    "opt_only_maxima": bool,
    "opt_only_minima": bool,
})
CiftiExtremaParametersTagged = typing.TypedDict('CiftiExtremaParametersTagged', {
    "@type": typing.Literal["workbench/cifti-extrema"],
    "cifti": InputPathType,
    "surface_distance": float,
    "volume_distance": float,
    "direction": str,
    "cifti_out": str,
    "opt_left_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_right_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_surface_presmooth_surface_kernel": typing.NotRequired[float | None],
    "opt_volume_presmooth_volume_kernel": typing.NotRequired[float | None],
    "opt_presmooth_fwhm": bool,
    "threshold": typing.NotRequired[CiftiExtremaThresholdParameters | None],
    "opt_merged_volume": bool,
    "opt_sum_maps": bool,
    "opt_consolidate_mode": bool,
    "opt_only_maxima": bool,
    "opt_only_minima": bool,
})


def cifti_extrema_threshold_params(
    low: float,
    high: float,
) -> CiftiExtremaThresholdParametersTagged:
    """
    Build parameters.
    
    Args:
        low: the largest value to consider for being a minimum.
        high: the smallest value to consider for being a maximum.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "threshold",
        "low": low,
        "high": high,
    }
    return params


def cifti_extrema_threshold_cargs(
    params: CiftiExtremaThresholdParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-threshold")
    cargs.append(str(params.get("low", None)))
    cargs.append(str(params.get("high", None)))
    return cargs


class CiftiExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiExtremaParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""


def cifti_extrema_params(
    cifti: InputPathType,
    surface_distance: float,
    volume_distance: float,
    direction: str,
    cifti_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
    opt_surface_presmooth_surface_kernel: float | None = None,
    opt_volume_presmooth_volume_kernel: float | None = None,
    opt_presmooth_fwhm: bool = False,
    threshold: CiftiExtremaThresholdParameters | None = None,
    opt_merged_volume: bool = False,
    opt_sum_maps: bool = False,
    opt_consolidate_mode: bool = False,
    opt_only_maxima: bool = False,
    opt_only_minima: bool = False,
) -> CiftiExtremaParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the input cifti.
        surface_distance: the minimum distance between extrema of the same\
            type, for surface components.
        volume_distance: the minimum distance between extrema of the same type,\
            for volume components.
        direction: which dimension to find extrema along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
        opt_surface_presmooth_surface_kernel: smooth on the surface before\
            finding extrema: the size of the gaussian surface smoothing kernel in\
            mm, as sigma by default.
        opt_volume_presmooth_volume_kernel: smooth volume components before\
            finding extrema: the size of the gaussian volume smoothing kernel in\
            mm, as sigma by default.
        opt_presmooth_fwhm: smoothing kernel distances are FWHM, not sigma.
        threshold: ignore small extrema.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        opt_sum_maps: output the sum of the extrema maps instead of each map\
            separately.
        opt_consolidate_mode: use consolidation of local minima instead of a\
            large neighborhood.
        opt_only_maxima: only find the maxima.
        opt_only_minima: only find the minima.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-extrema",
        "cifti": cifti,
        "surface_distance": surface_distance,
        "volume_distance": volume_distance,
        "direction": direction,
        "cifti_out": cifti_out,
        "opt_presmooth_fwhm": opt_presmooth_fwhm,
        "opt_merged_volume": opt_merged_volume,
        "opt_sum_maps": opt_sum_maps,
        "opt_consolidate_mode": opt_consolidate_mode,
        "opt_only_maxima": opt_only_maxima,
        "opt_only_minima": opt_only_minima,
    }
    if opt_left_surface_surface is not None:
        params["opt_left_surface_surface"] = opt_left_surface_surface
    if opt_right_surface_surface is not None:
        params["opt_right_surface_surface"] = opt_right_surface_surface
    if opt_cerebellum_surface_surface is not None:
        params["opt_cerebellum_surface_surface"] = opt_cerebellum_surface_surface
    if opt_surface_presmooth_surface_kernel is not None:
        params["opt_surface_presmooth_surface_kernel"] = opt_surface_presmooth_surface_kernel
    if opt_volume_presmooth_volume_kernel is not None:
        params["opt_volume_presmooth_volume_kernel"] = opt_volume_presmooth_volume_kernel
    if threshold is not None:
        params["threshold"] = threshold
    return params


def cifti_extrema_cargs(
    params: CiftiExtremaParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-extrema")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(str(params.get("surface_distance", None)))
    cargs.append(str(params.get("volume_distance", None)))
    cargs.append(params.get("direction", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_left_surface_surface", None) is not None:
        cargs.extend([
            "-left-surface",
            execution.input_file(params.get("opt_left_surface_surface", None))
        ])
    if params.get("opt_right_surface_surface", None) is not None:
        cargs.extend([
            "-right-surface",
            execution.input_file(params.get("opt_right_surface_surface", None))
        ])
    if params.get("opt_cerebellum_surface_surface", None) is not None:
        cargs.extend([
            "-cerebellum-surface",
            execution.input_file(params.get("opt_cerebellum_surface_surface", None))
        ])
    if params.get("opt_surface_presmooth_surface_kernel", None) is not None:
        cargs.extend([
            "-surface-presmooth",
            str(params.get("opt_surface_presmooth_surface_kernel", None))
        ])
    if params.get("opt_volume_presmooth_volume_kernel", None) is not None:
        cargs.extend([
            "-volume-presmooth",
            str(params.get("opt_volume_presmooth_volume_kernel", None))
        ])
    if params.get("opt_presmooth_fwhm", False):
        cargs.append("-presmooth-fwhm")
    if params.get("threshold", None) is not None:
        cargs.extend(cifti_extrema_threshold_cargs(params.get("threshold", None), execution))
    if params.get("opt_merged_volume", False):
        cargs.append("-merged-volume")
    if params.get("opt_sum_maps", False):
        cargs.append("-sum-maps")
    if params.get("opt_consolidate_mode", False):
        cargs.append("-consolidate-mode")
    if params.get("opt_only_maxima", False):
        cargs.append("-only-maxima")
    if params.get("opt_only_minima", False):
        cargs.append("-only-minima")
    return cargs


def cifti_extrema_outputs(
    params: CiftiExtremaParameters,
    execution: Execution,
) -> CiftiExtremaOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiExtremaOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_extrema_execute(
    params: CiftiExtremaParameters,
    runner: Runner | None = None,
) -> CiftiExtremaOutputs:
    """
    cifti-extrema
    
    Find extrema in a cifti file.
    
    Finds spatial locations in a cifti file that have more extreme values than
    all nearby locations in the same component (surface or volume structure).
    The input cifti file must have a brain models mapping along the specified
    direction. COLUMN is the direction that works on dtseries and dscalar. For
    dconn, if it is symmetric use COLUMN, otherwise use ROW.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_EXTREMA_METADATA)
    params = execution.params(params)
    cargs = cifti_extrema_cargs(params, execution)
    ret = cifti_extrema_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_extrema(
    cifti: InputPathType,
    surface_distance: float,
    volume_distance: float,
    direction: str,
    cifti_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
    opt_surface_presmooth_surface_kernel: float | None = None,
    opt_volume_presmooth_volume_kernel: float | None = None,
    opt_presmooth_fwhm: bool = False,
    threshold: CiftiExtremaThresholdParameters | None = None,
    opt_merged_volume: bool = False,
    opt_sum_maps: bool = False,
    opt_consolidate_mode: bool = False,
    opt_only_maxima: bool = False,
    opt_only_minima: bool = False,
    runner: Runner | None = None,
) -> CiftiExtremaOutputs:
    """
    cifti-extrema
    
    Find extrema in a cifti file.
    
    Finds spatial locations in a cifti file that have more extreme values than
    all nearby locations in the same component (surface or volume structure).
    The input cifti file must have a brain models mapping along the specified
    direction. COLUMN is the direction that works on dtseries and dscalar. For
    dconn, if it is symmetric use COLUMN, otherwise use ROW.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the input cifti.
        surface_distance: the minimum distance between extrema of the same\
            type, for surface components.
        volume_distance: the minimum distance between extrema of the same type,\
            for volume components.
        direction: which dimension to find extrema along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
        opt_surface_presmooth_surface_kernel: smooth on the surface before\
            finding extrema: the size of the gaussian surface smoothing kernel in\
            mm, as sigma by default.
        opt_volume_presmooth_volume_kernel: smooth volume components before\
            finding extrema: the size of the gaussian volume smoothing kernel in\
            mm, as sigma by default.
        opt_presmooth_fwhm: smoothing kernel distances are FWHM, not sigma.
        threshold: ignore small extrema.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        opt_sum_maps: output the sum of the extrema maps instead of each map\
            separately.
        opt_consolidate_mode: use consolidation of local minima instead of a\
            large neighborhood.
        opt_only_maxima: only find the maxima.
        opt_only_minima: only find the minima.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiExtremaOutputs`).
    """
    params = cifti_extrema_params(
        cifti=cifti,
        surface_distance=surface_distance,
        volume_distance=volume_distance,
        direction=direction,
        cifti_out=cifti_out,
        opt_left_surface_surface=opt_left_surface_surface,
        opt_right_surface_surface=opt_right_surface_surface,
        opt_cerebellum_surface_surface=opt_cerebellum_surface_surface,
        opt_surface_presmooth_surface_kernel=opt_surface_presmooth_surface_kernel,
        opt_volume_presmooth_volume_kernel=opt_volume_presmooth_volume_kernel,
        opt_presmooth_fwhm=opt_presmooth_fwhm,
        threshold=threshold,
        opt_merged_volume=opt_merged_volume,
        opt_sum_maps=opt_sum_maps,
        opt_consolidate_mode=opt_consolidate_mode,
        opt_only_maxima=opt_only_maxima,
        opt_only_minima=opt_only_minima,
    )
    return cifti_extrema_execute(params, runner)


__all__ = [
    "CIFTI_EXTREMA_METADATA",
    "CiftiExtremaOutputs",
    "cifti_extrema",
    "cifti_extrema_execute",
    "cifti_extrema_params",
    "cifti_extrema_threshold_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

FILE_CONVERT_METADATA = Metadata(
    id="2ba9bfe538f65b507e6368c6504e85d0210593d5.boutiques",
    name="file-convert",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


FileConvertBorderVersionConvertParameters = typing.TypedDict('FileConvertBorderVersionConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["border_version_convert"]],
    "border_in": InputPathType,
    "out_version": int,
    "border_out": str,
    "opt_surface_surface": typing.NotRequired[InputPathType | None],
})
FileConvertBorderVersionConvertParametersTagged = typing.TypedDict('FileConvertBorderVersionConvertParametersTagged', {
    "@type": typing.Literal["border_version_convert"],
    "border_in": InputPathType,
    "out_version": int,
    "border_out": str,
    "opt_surface_surface": typing.NotRequired[InputPathType | None],
})


FileConvertNiftiVersionConvertParameters = typing.TypedDict('FileConvertNiftiVersionConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["nifti_version_convert"]],
    "input": str,
    "version": int,
    "output": str,
})
FileConvertNiftiVersionConvertParametersTagged = typing.TypedDict('FileConvertNiftiVersionConvertParametersTagged', {
    "@type": typing.Literal["nifti_version_convert"],
    "input": str,
    "version": int,
    "output": str,
})


FileConvertCiftiVersionConvertParameters = typing.TypedDict('FileConvertCiftiVersionConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["cifti_version_convert"]],
    "cifti_in": InputPathType,
    "version": str,
    "cifti_out": str,
})
FileConvertCiftiVersionConvertParametersTagged = typing.TypedDict('FileConvertCiftiVersionConvertParametersTagged', {
    "@type": typing.Literal["cifti_version_convert"],
    "cifti_in": InputPathType,
    "version": str,
    "cifti_out": str,
})


FileConvertParameters = typing.TypedDict('FileConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/file-convert"]],
    "border_version_convert": typing.NotRequired[FileConvertBorderVersionConvertParameters | None],
    "nifti_version_convert": typing.NotRequired[FileConvertNiftiVersionConvertParameters | None],
    "cifti_version_convert": typing.NotRequired[FileConvertCiftiVersionConvertParameters | None],
})
FileConvertParametersTagged = typing.TypedDict('FileConvertParametersTagged', {
    "@type": typing.Literal["workbench/file-convert"],
    "border_version_convert": typing.NotRequired[FileConvertBorderVersionConvertParameters | None],
    "nifti_version_convert": typing.NotRequired[FileConvertNiftiVersionConvertParameters | None],
    "cifti_version_convert": typing.NotRequired[FileConvertCiftiVersionConvertParameters | None],
})


def file_convert_border_version_convert_params(
    border_in: InputPathType,
    out_version: int,
    border_out: str,
    opt_surface_surface: InputPathType | None = None,
) -> FileConvertBorderVersionConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        border_in: the input border file.
        out_version: the format version to write as, 1 or 3 (2 doesn't exist).
        border_out: output - the output border file.
        opt_surface_surface: must be specified if the input is version 1: use\
            this surface file for structure and number of vertices, ignore borders\
            on other structures.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "border_version_convert",
        "border_in": border_in,
        "out_version": out_version,
        "border_out": border_out,
    }
    if opt_surface_surface is not None:
        params["opt_surface_surface"] = opt_surface_surface
    return params


def file_convert_border_version_convert_cargs(
    params: FileConvertBorderVersionConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-border-version-convert")
    cargs.append(execution.input_file(params.get("border_in", None)))
    cargs.append(str(params.get("out_version", None)))
    cargs.append(params.get("border_out", None))
    if params.get("opt_surface_surface", None) is not None:
        cargs.extend([
            "-surface",
            execution.input_file(params.get("opt_surface_surface", None))
        ])
    return cargs


def file_convert_nifti_version_convert_params(
    input_: str,
    version: int,
    output: str,
) -> FileConvertNiftiVersionConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        input_: the input nifti file.
        version: the nifti version to write as.
        output: output - the output nifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "nifti_version_convert",
        "input": input_,
        "version": version,
        "output": output,
    }
    return params


def file_convert_nifti_version_convert_cargs(
    params: FileConvertNiftiVersionConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-nifti-version-convert")
    cargs.append(params.get("input", None))
    cargs.append(str(params.get("version", None)))
    cargs.append(params.get("output", None))
    return cargs


def file_convert_cifti_version_convert_params(
    cifti_in: InputPathType,
    version: str,
    cifti_out: str,
) -> FileConvertCiftiVersionConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti file.
        version: the cifti version to write as.
        cifti_out: output - the output cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cifti_version_convert",
        "cifti_in": cifti_in,
        "version": version,
        "cifti_out": cifti_out,
    }
    return params


def file_convert_cifti_version_convert_cargs(
    params: FileConvertCiftiVersionConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cifti-version-convert")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("version", None))
    cargs.append(params.get("cifti_out", None))
    return cargs


class FileConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `FileConvertParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def file_convert_params(
    border_version_convert: FileConvertBorderVersionConvertParameters | None = None,
    nifti_version_convert: FileConvertNiftiVersionConvertParameters | None = None,
    cifti_version_convert: FileConvertCiftiVersionConvertParameters | None = None,
) -> FileConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        border_version_convert: write a border file with a different version.
        nifti_version_convert: write a nifti file with a different version.
        cifti_version_convert: write a cifti file with a different version.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/file-convert",
    }
    if border_version_convert is not None:
        params["border_version_convert"] = border_version_convert
    if nifti_version_convert is not None:
        params["nifti_version_convert"] = nifti_version_convert
    if cifti_version_convert is not None:
        params["cifti_version_convert"] = cifti_version_convert
    return params


def file_convert_cargs(
    params: FileConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-file-convert")
    if params.get("border_version_convert", None) is not None:
        cargs.extend(file_convert_border_version_convert_cargs(params.get("border_version_convert", None), execution))
    if params.get("nifti_version_convert", None) is not None:
        cargs.extend(file_convert_nifti_version_convert_cargs(params.get("nifti_version_convert", None), execution))
    if params.get("cifti_version_convert", None) is not None:
        cargs.extend(file_convert_cifti_version_convert_cargs(params.get("cifti_version_convert", None), execution))
    return cargs


def file_convert_outputs(
    params: FileConvertParameters,
    execution: Execution,
) -> FileConvertOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = FileConvertOutputs(
        root=execution.output_file("."),
    )
    return ret


def file_convert_execute(
    params: FileConvertParameters,
    runner: Runner | None = None,
) -> FileConvertOutputs:
    """
    file-convert
    
    Change version of file format.
    
    You may only specify one top-level option.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FileConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILE_CONVERT_METADATA)
    params = execution.params(params)
    cargs = file_convert_cargs(params, execution)
    ret = file_convert_outputs(params, execution)
    execution.run(cargs)
    return ret


def file_convert(
    border_version_convert: FileConvertBorderVersionConvertParameters | None = None,
    nifti_version_convert: FileConvertNiftiVersionConvertParameters | None = None,
    cifti_version_convert: FileConvertCiftiVersionConvertParameters | None = None,
    runner: Runner | None = None,
) -> FileConvertOutputs:
    """
    file-convert
    
    Change version of file format.
    
    You may only specify one top-level option.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        border_version_convert: write a border file with a different version.
        nifti_version_convert: write a nifti file with a different version.
        cifti_version_convert: write a cifti file with a different version.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FileConvertOutputs`).
    """
    params = file_convert_params(
        border_version_convert=border_version_convert,
        nifti_version_convert=nifti_version_convert,
        cifti_version_convert=cifti_version_convert,
    )
    return file_convert_execute(params, runner)


__all__ = [
    "FILE_CONVERT_METADATA",
    "FileConvertOutputs",
    "file_convert",
    "file_convert_border_version_convert_params",
    "file_convert_cifti_version_convert_params",
    "file_convert_execute",
    "file_convert_nifti_version_convert_params",
    "file_convert_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_SPHERE_PROJECT_UNPROJECT_METADATA = Metadata(
    id="ec00569346766fa83a8b274b19856b08f237baba.boutiques",
    name="surface-sphere-project-unproject",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceSphereProjectUnprojectParameters = typing.TypedDict('SurfaceSphereProjectUnprojectParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-sphere-project-unproject"]],
    "sphere_in": InputPathType,
    "sphere_project_to": InputPathType,
    "sphere_unproject_from": InputPathType,
    "sphere_out": str,
})
SurfaceSphereProjectUnprojectParametersTagged = typing.TypedDict('SurfaceSphereProjectUnprojectParametersTagged', {
    "@type": typing.Literal["workbench/surface-sphere-project-unproject"],
    "sphere_in": InputPathType,
    "sphere_project_to": InputPathType,
    "sphere_unproject_from": InputPathType,
    "sphere_out": str,
})


class SurfaceSphereProjectUnprojectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceSphereProjectUnprojectParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sphere_out: OutputPathType
    """the output sphere"""


def surface_sphere_project_unproject_params(
    sphere_in: InputPathType,
    sphere_project_to: InputPathType,
    sphere_unproject_from: InputPathType,
    sphere_out: str,
) -> SurfaceSphereProjectUnprojectParametersTagged:
    """
    Build parameters.
    
    Args:
        sphere_in: a sphere with the desired output mesh.
        sphere_project_to: a sphere that aligns with sphere-in.
        sphere_unproject_from: <sphere-project-to> deformed to the desired\
            output space.
        sphere_out: the output sphere.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-sphere-project-unproject",
        "sphere_in": sphere_in,
        "sphere_project_to": sphere_project_to,
        "sphere_unproject_from": sphere_unproject_from,
        "sphere_out": sphere_out,
    }
    return params


def surface_sphere_project_unproject_cargs(
    params: SurfaceSphereProjectUnprojectParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-sphere-project-unproject")
    cargs.append(execution.input_file(params.get("sphere_in", None)))
    cargs.append(execution.input_file(params.get("sphere_project_to", None)))
    cargs.append(execution.input_file(params.get("sphere_unproject_from", None)))
    cargs.append(params.get("sphere_out", None))
    return cargs


def surface_sphere_project_unproject_outputs(
    params: SurfaceSphereProjectUnprojectParameters,
    execution: Execution,
) -> SurfaceSphereProjectUnprojectOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceSphereProjectUnprojectOutputs(
        root=execution.output_file("."),
        sphere_out=execution.output_file(params.get("sphere_out", None)),
    )
    return ret


def surface_sphere_project_unproject_execute(
    params: SurfaceSphereProjectUnprojectParameters,
    runner: Runner | None = None,
) -> SurfaceSphereProjectUnprojectOutputs:
    """
    surface-sphere-project-unproject
    
    Copy registration deformations to different sphere.
    
    Background: A surface registration starts with an input sphere, and moves
    its vertices around on the sphere until it matches the template data. This
    means that the registration deformation is actually represented as the
    difference between two separate files - the starting sphere, and the
    registered sphere. Since the starting sphere of the registration may not
    have vertex correspondence to any other sphere (often, it is a native
    sphere), it can be inconvenient to manipulate or compare these deformations
    across subjects, etc.
    
    The purpose of this command is to be able to apply these deformations onto a
    new sphere of the user's choice, to make it easier to compare or manipulate
    them. Common uses are to concatenate two successive separate registrations
    (e.g. Human to Chimpanzee, and then Chimpanzee to Macaque) or inversion (for
    dedrifting or symmetric registration schemes).
    
    <sphere-in> must already be considered to be in alignment with one of the
    two ends of the registration (if your registration is Human to Chimpanzee,
    <sphere-in> must be in register with either Human or Chimpanzee). The
    'project-to' sphere must be the side of the registration that is aligned
    with <sphere-in> (if your registration is Human to Chimpanzee, and
    <sphere-in> is aligned with Human, then 'project-to' should be the original
    Human sphere). The 'unproject-from' sphere must be the remaining sphere of
    the registration (original vs deformed/registered). The output is as if you
    had run the same registration with <sphere-in> as the starting sphere, in
    the direction of deforming the 'project-to' sphere to create the
    'unproject-from' sphere.
    
    Note that this command cannot check for you what spheres are aligned with
    other spheres, and using the wrong spheres or in the incorrect order will
    not necessarily cause an error message. In some cases, it may be useful to
    use a new, arbitrary sphere as the input, which can be created with the
    -surface-create-sphere command.
    
    Example 1: You have a Human to Chimpanzee registration, and a Chimpanzee to
    Macaque registration, and want to combine them. If you use the Human sphere
    registered to Chimpanzee as sphere-in, the Chimpanzee standard sphere as
    project-to, and the Chimpanzee sphere registered to Macaque as
    unproject-from, the output will be the Human sphere in register with the
    Macaque.
    
    Example 2: You have a Human to Chimpanzee registration, but what you really
    want is the inverse, that is, the sphere as if you had run the registration
    from Chimpanzee to Human. If you use the Chimpanzee standard sphere as
    sphere-in, the Human sphere registered to Chimpanzee as project-to, and the
    standard Human sphere as unproject-from, the output will be the Chimpanzee
    sphere in register with the Human.
    
    Technical details: Each vertex of <sphere-in> is projected to a triangle of
    <sphere-project-to>, and its new position is determined by the position of
    the corresponding triangle in <sphere-unproject-from>. The output is a
    sphere with the topology of <sphere-in>, but coordinates shifted by the
    deformation from <sphere-project-to> to <sphere-unproject-from>.
    <sphere-project-to> and <sphere-unproject-from> must have the same topology
    as each other, but <sphere-in> may have any topology.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSphereProjectUnprojectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_SPHERE_PROJECT_UNPROJECT_METADATA)
    params = execution.params(params)
    cargs = surface_sphere_project_unproject_cargs(params, execution)
    ret = surface_sphere_project_unproject_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_sphere_project_unproject(
    sphere_in: InputPathType,
    sphere_project_to: InputPathType,
    sphere_unproject_from: InputPathType,
    sphere_out: str,
    runner: Runner | None = None,
) -> SurfaceSphereProjectUnprojectOutputs:
    """
    surface-sphere-project-unproject
    
    Copy registration deformations to different sphere.
    
    Background: A surface registration starts with an input sphere, and moves
    its vertices around on the sphere until it matches the template data. This
    means that the registration deformation is actually represented as the
    difference between two separate files - the starting sphere, and the
    registered sphere. Since the starting sphere of the registration may not
    have vertex correspondence to any other sphere (often, it is a native
    sphere), it can be inconvenient to manipulate or compare these deformations
    across subjects, etc.
    
    The purpose of this command is to be able to apply these deformations onto a
    new sphere of the user's choice, to make it easier to compare or manipulate
    them. Common uses are to concatenate two successive separate registrations
    (e.g. Human to Chimpanzee, and then Chimpanzee to Macaque) or inversion (for
    dedrifting or symmetric registration schemes).
    
    <sphere-in> must already be considered to be in alignment with one of the
    two ends of the registration (if your registration is Human to Chimpanzee,
    <sphere-in> must be in register with either Human or Chimpanzee). The
    'project-to' sphere must be the side of the registration that is aligned
    with <sphere-in> (if your registration is Human to Chimpanzee, and
    <sphere-in> is aligned with Human, then 'project-to' should be the original
    Human sphere). The 'unproject-from' sphere must be the remaining sphere of
    the registration (original vs deformed/registered). The output is as if you
    had run the same registration with <sphere-in> as the starting sphere, in
    the direction of deforming the 'project-to' sphere to create the
    'unproject-from' sphere.
    
    Note that this command cannot check for you what spheres are aligned with
    other spheres, and using the wrong spheres or in the incorrect order will
    not necessarily cause an error message. In some cases, it may be useful to
    use a new, arbitrary sphere as the input, which can be created with the
    -surface-create-sphere command.
    
    Example 1: You have a Human to Chimpanzee registration, and a Chimpanzee to
    Macaque registration, and want to combine them. If you use the Human sphere
    registered to Chimpanzee as sphere-in, the Chimpanzee standard sphere as
    project-to, and the Chimpanzee sphere registered to Macaque as
    unproject-from, the output will be the Human sphere in register with the
    Macaque.
    
    Example 2: You have a Human to Chimpanzee registration, but what you really
    want is the inverse, that is, the sphere as if you had run the registration
    from Chimpanzee to Human. If you use the Chimpanzee standard sphere as
    sphere-in, the Human sphere registered to Chimpanzee as project-to, and the
    standard Human sphere as unproject-from, the output will be the Chimpanzee
    sphere in register with the Human.
    
    Technical details: Each vertex of <sphere-in> is projected to a triangle of
    <sphere-project-to>, and its new position is determined by the position of
    the corresponding triangle in <sphere-unproject-from>. The output is a
    sphere with the topology of <sphere-in>, but coordinates shifted by the
    deformation from <sphere-project-to> to <sphere-unproject-from>.
    <sphere-project-to> and <sphere-unproject-from> must have the same topology
    as each other, but <sphere-in> may have any topology.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        sphere_in: a sphere with the desired output mesh.
        sphere_project_to: a sphere that aligns with sphere-in.
        sphere_unproject_from: <sphere-project-to> deformed to the desired\
            output space.
        sphere_out: the output sphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSphereProjectUnprojectOutputs`).
    """
    params = surface_sphere_project_unproject_params(
        sphere_in=sphere_in,
        sphere_project_to=sphere_project_to,
        sphere_unproject_from=sphere_unproject_from,
        sphere_out=sphere_out,
    )
    return surface_sphere_project_unproject_execute(params, runner)


__all__ = [
    "SURFACE_SPHERE_PROJECT_UNPROJECT_METADATA",
    "SurfaceSphereProjectUnprojectOutputs",
    "surface_sphere_project_unproject",
    "surface_sphere_project_unproject_execute",
    "surface_sphere_project_unproject_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

GIFTI_CONVERT_METADATA = Metadata(
    id="00ca05307d704bb4b72ca8d609e922d80aac69c0.boutiques",
    name="gifti-convert",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


GiftiConvertParameters = typing.TypedDict('GiftiConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/gifti-convert"]],
    "gifti_encoding": str,
    "input_gifti_file": str,
    "output_gifti_file": str,
})
GiftiConvertParametersTagged = typing.TypedDict('GiftiConvertParametersTagged', {
    "@type": typing.Literal["workbench/gifti-convert"],
    "gifti_encoding": str,
    "input_gifti_file": str,
    "output_gifti_file": str,
})


class GiftiConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `GiftiConvertParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gifti_convert_params(
    gifti_encoding: str,
    input_gifti_file: str,
    output_gifti_file: str,
) -> GiftiConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        gifti_encoding: what the output encoding should be.
        input_gifti_file: the input gifti file.
        output_gifti_file: output - the output gifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/gifti-convert",
        "gifti_encoding": gifti_encoding,
        "input_gifti_file": input_gifti_file,
        "output_gifti_file": output_gifti_file,
    }
    return params


def gifti_convert_cargs(
    params: GiftiConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-gifti-convert")
    cargs.append(params.get("gifti_encoding", None))
    cargs.append(params.get("input_gifti_file", None))
    cargs.append(params.get("output_gifti_file", None))
    return cargs


def gifti_convert_outputs(
    params: GiftiConvertParameters,
    execution: Execution,
) -> GiftiConvertOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = GiftiConvertOutputs(
        root=execution.output_file("."),
    )
    return ret


def gifti_convert_execute(
    params: GiftiConvertParameters,
    runner: Runner | None = None,
) -> GiftiConvertOutputs:
    """
    gifti-convert
    
    Convert a gifti file to a different encoding.
    
    The value of <gifti-encoding> must be one of the following:
    
    ASCII
    BASE64_BINARY
    GZIP_BASE64_BINARY
    EXTERNAL_FILE_BINARY.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_CONVERT_METADATA)
    params = execution.params(params)
    cargs = gifti_convert_cargs(params, execution)
    ret = gifti_convert_outputs(params, execution)
    execution.run(cargs)
    return ret


def gifti_convert(
    gifti_encoding: str,
    input_gifti_file: str,
    output_gifti_file: str,
    runner: Runner | None = None,
) -> GiftiConvertOutputs:
    """
    gifti-convert
    
    Convert a gifti file to a different encoding.
    
    The value of <gifti-encoding> must be one of the following:
    
    ASCII
    BASE64_BINARY
    GZIP_BASE64_BINARY
    EXTERNAL_FILE_BINARY.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        gifti_encoding: what the output encoding should be.
        input_gifti_file: the input gifti file.
        output_gifti_file: output - the output gifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiConvertOutputs`).
    """
    params = gifti_convert_params(
        gifti_encoding=gifti_encoding,
        input_gifti_file=input_gifti_file,
        output_gifti_file=output_gifti_file,
    )
    return gifti_convert_execute(params, runner)


__all__ = [
    "GIFTI_CONVERT_METADATA",
    "GiftiConvertOutputs",
    "gifti_convert",
    "gifti_convert_execute",
    "gifti_convert_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_MATH_METADATA = Metadata(
    id="452fbf26e7e7dec769a52f1743e09cb940aeff81.boutiques",
    name="cifti-math",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiMathSelectParameters = typing.TypedDict('CiftiMathSelectParameters', {
    "@type": typing.NotRequired[typing.Literal["select"]],
    "dim": int,
    "index": str,
    "opt_repeat": bool,
})
CiftiMathSelectParametersTagged = typing.TypedDict('CiftiMathSelectParametersTagged', {
    "@type": typing.Literal["select"],
    "dim": int,
    "index": str,
    "opt_repeat": bool,
})


CiftiMathVarParameters = typing.TypedDict('CiftiMathVarParameters', {
    "@type": typing.NotRequired[typing.Literal["var"]],
    "name": str,
    "cifti": InputPathType,
    "select": typing.NotRequired[list[CiftiMathSelectParameters] | None],
})
CiftiMathVarParametersTagged = typing.TypedDict('CiftiMathVarParametersTagged', {
    "@type": typing.Literal["var"],
    "name": str,
    "cifti": InputPathType,
    "select": typing.NotRequired[list[CiftiMathSelectParameters] | None],
})


CiftiMathParameters = typing.TypedDict('CiftiMathParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-math"]],
    "expression": str,
    "cifti_out": str,
    "opt_fixnan_replace": typing.NotRequired[float | None],
    "opt_override_mapping_check": bool,
    "var": typing.NotRequired[list[CiftiMathVarParameters] | None],
})
CiftiMathParametersTagged = typing.TypedDict('CiftiMathParametersTagged', {
    "@type": typing.Literal["workbench/cifti-math"],
    "expression": str,
    "cifti_out": str,
    "opt_fixnan_replace": typing.NotRequired[float | None],
    "opt_override_mapping_check": bool,
    "var": typing.NotRequired[list[CiftiMathVarParameters] | None],
})


def cifti_math_select_params(
    dim: int,
    index: str,
    opt_repeat: bool = False,
) -> CiftiMathSelectParametersTagged:
    """
    Build parameters.
    
    Args:
        dim: the dimension to select from (1-based).
        index: the index number (1-based) or map name to use.
        opt_repeat: repeat the selected values for each index of output in this\
            dimension.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "select",
        "dim": dim,
        "index": index,
        "opt_repeat": opt_repeat,
    }
    return params


def cifti_math_select_cargs(
    params: CiftiMathSelectParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-select")
    cargs.append(str(params.get("dim", None)))
    cargs.append(params.get("index", None))
    if params.get("opt_repeat", False):
        cargs.append("-repeat")
    return cargs


def cifti_math_var_params(
    name: str,
    cifti: InputPathType,
    select_: list[CiftiMathSelectParameters] | None = None,
) -> CiftiMathVarParametersTagged:
    """
    Build parameters.
    
    Args:
        name: the name of the variable, as used in the expression.
        cifti: the cifti file to use as this variable.
        select_: select a single index from a dimension.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "var",
        "name": name,
        "cifti": cifti,
    }
    if select_ is not None:
        params["select"] = select_
    return params


def cifti_math_var_cargs(
    params: CiftiMathVarParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-var")
    cargs.append(params.get("name", None))
    cargs.append(execution.input_file(params.get("cifti", None)))
    if params.get("select", None) is not None:
        cargs.extend([a for c in [cifti_math_select_cargs(s, execution) for s in params.get("select", None)] for a in c])
    return cargs


class CiftiMathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiMathParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_math_params(
    expression: str,
    cifti_out: str,
    opt_fixnan_replace: float | None = None,
    opt_override_mapping_check: bool = False,
    var: list[CiftiMathVarParameters] | None = None,
) -> CiftiMathParametersTagged:
    """
    Build parameters.
    
    Args:
        expression: the expression to evaluate, in quotes.
        cifti_out: the output cifti file.
        opt_fixnan_replace: replace NaN results with a value: value to replace\
            NaN with.
        opt_override_mapping_check: don't check the mappings for compatibility,\
            only check length.
        var: a cifti file to use as a variable.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-math",
        "expression": expression,
        "cifti_out": cifti_out,
        "opt_override_mapping_check": opt_override_mapping_check,
    }
    if opt_fixnan_replace is not None:
        params["opt_fixnan_replace"] = opt_fixnan_replace
    if var is not None:
        params["var"] = var
    return params


def cifti_math_cargs(
    params: CiftiMathParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-math")
    cargs.append(params.get("expression", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_fixnan_replace", None) is not None:
        cargs.extend([
            "-fixnan",
            str(params.get("opt_fixnan_replace", None))
        ])
    if params.get("opt_override_mapping_check", False):
        cargs.append("-override-mapping-check")
    if params.get("var", None) is not None:
        cargs.extend([a for c in [cifti_math_var_cargs(s, execution) for s in params.get("var", None)] for a in c])
    return cargs


def cifti_math_outputs(
    params: CiftiMathParameters,
    execution: Execution,
) -> CiftiMathOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiMathOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_math_execute(
    params: CiftiMathParameters,
    runner: Runner | None = None,
) -> CiftiMathOutputs:
    """
    cifti-math
    
    Evaluate expression on cifti files.
    
    This command evaluates <expression> at each matrix element independently.
    There must be at least one -var option (to get the output layout from), even
    if the <name> specified in it isn't used in <expression>.
    
    To select a single column from a 2D file (most cifti files are 2D), use
    -select 1 <index>, where <index> is 1-based. To select a single row from a
    2D file, use -select 2 <index>. Where -select is not used, the cifti files
    must have compatible mappings (e.g., brain models and parcels mappings must
    match exactly except for parcel names). Use -override-mapping-check to skip
    this checking.
    
    Filenames are not valid in <expression>, use a variable name and a -var
    option with matching <name> to specify an input file. The format of
    <expression> is as follows:
    
    Expressions consist of constants, variables, operators, parentheses, and
    functions, in infix notation, such as 'exp(-x + 3) * scale'. Variables are
    strings of any length, using the characters a-z, A-Z, 0-9, and _, but may
    not take the name of a named constant. Currently, there is only one named
    constant, PI. The operators are +, -, *, /, ^, >, <, >=, <=, ==, !=, !, &&,
    ||. These behave as in C, except that ^ is exponentiation, i.e. pow(x, y),
    and takes higher precedence than other binary operators (also, '-3^-4^-5'
    means '-(3^(-(4^-5)))'). The <=, >=, ==, and != operators are given a small
    amount of wiggle room, equal to one millionth of the smaller of the absolute
    values of the values being compared.
    
    Comparison and logical operators return 0 or 1, you can do masking with
    expressions like 'x * (mask > 0)'. For all logical operators, an input is
    considered true iff it is greater than 0. The expression '0 < x < 5' is not
    syntactically wrong, but it will NOT do what is desired, because it is
    evaluated left to right, i.e. '((0 < x) < 5)', which will always return 1,
    as both possible results of a comparison are less than 5. A warning is
    generated if an expression of this type is detected. Use something like 'x >
    0 && x < 5' to get the desired behavior.
    
    Whitespace between elements is ignored, ' sin ( 2 * x ) ' is equivalent to
    'sin(2*x)', but 's in(2*x)' is an error. Implied multiplication is not
    allowed, the expression '2x' will be parsed as a variable. Parentheses are
    (), do not use [] or {}. Functions require parentheses, the expression 'sin
    x' is an error.
    
    The following functions are supported:
    
    sin: 1 argument, the sine of the argument (units are radians)
    cos: 1 argument, the cosine of the argument (units are radians)
    tan: 1 argument, the tangent of the argument (units are radians)
    asin: 1 argument, the inverse of sine of the argument, in radians
    acos: 1 argument, the inverse of cosine of the argument, in radians
    atan: 1 argument, the inverse of tangent of the argument, in radians
    atan2: 2 arguments, atan2(y, x) returns the inverse of tangent of (y/x), in
    radians, determining quadrant by the sign of both arguments
    sinh: 1 argument, the hyperbolic sine of the argument
    cosh: 1 argument, the hyperbolic cosine of the argument
    tanh: 1 argument, the hyperbolic tangent of the argument
    asinh: 1 argument, the inverse hyperbolic sine of the argument
    acosh: 1 argument, the inverse hyperbolic cosine of the argument
    atanh: 1 argument, the inverse hyperbolic tangent of the argument
    sinc: 1 argument, sinc(0) = 1, sin(x) / x otherwise
    ln: 1 argument, the natural logarithm of the argument
    exp: 1 argument, the constant e raised to the power of the argument
    log: 1 argument, the base 10 logarithm of the argument
    log2: 1 argument, the base 2 logarithm of the argument
    sqrt: 1 argument, the square root of the argument
    abs: 1 argument, the absolute value of the argument
    floor: 1 argument, the largest integer not greater than the argument
    round: 1 argument, the nearest integer, with ties rounded away from zero
    ceil: 1 argument, the smallest integer not less than the argument
    min: 2 arguments, min(x, y) returns y if (x > y), x otherwise
    max: 2 arguments, max(x, y) returns y if (x < y), x otherwise
    mod: 2 arguments, mod(x, y) = x - y * floor(x / y), or 0 if y == 0
    clamp: 3 arguments, clamp(x, low, high) = min(max(x, low), high)
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiMathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_MATH_METADATA)
    params = execution.params(params)
    cargs = cifti_math_cargs(params, execution)
    ret = cifti_math_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_math(
    expression: str,
    cifti_out: str,
    opt_fixnan_replace: float | None = None,
    opt_override_mapping_check: bool = False,
    var: list[CiftiMathVarParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiMathOutputs:
    """
    cifti-math
    
    Evaluate expression on cifti files.
    
    This command evaluates <expression> at each matrix element independently.
    There must be at least one -var option (to get the output layout from), even
    if the <name> specified in it isn't used in <expression>.
    
    To select a single column from a 2D file (most cifti files are 2D), use
    -select 1 <index>, where <index> is 1-based. To select a single row from a
    2D file, use -select 2 <index>. Where -select is not used, the cifti files
    must have compatible mappings (e.g., brain models and parcels mappings must
    match exactly except for parcel names). Use -override-mapping-check to skip
    this checking.
    
    Filenames are not valid in <expression>, use a variable name and a -var
    option with matching <name> to specify an input file. The format of
    <expression> is as follows:
    
    Expressions consist of constants, variables, operators, parentheses, and
    functions, in infix notation, such as 'exp(-x + 3) * scale'. Variables are
    strings of any length, using the characters a-z, A-Z, 0-9, and _, but may
    not take the name of a named constant. Currently, there is only one named
    constant, PI. The operators are +, -, *, /, ^, >, <, >=, <=, ==, !=, !, &&,
    ||. These behave as in C, except that ^ is exponentiation, i.e. pow(x, y),
    and takes higher precedence than other binary operators (also, '-3^-4^-5'
    means '-(3^(-(4^-5)))'). The <=, >=, ==, and != operators are given a small
    amount of wiggle room, equal to one millionth of the smaller of the absolute
    values of the values being compared.
    
    Comparison and logical operators return 0 or 1, you can do masking with
    expressions like 'x * (mask > 0)'. For all logical operators, an input is
    considered true iff it is greater than 0. The expression '0 < x < 5' is not
    syntactically wrong, but it will NOT do what is desired, because it is
    evaluated left to right, i.e. '((0 < x) < 5)', which will always return 1,
    as both possible results of a comparison are less than 5. A warning is
    generated if an expression of this type is detected. Use something like 'x >
    0 && x < 5' to get the desired behavior.
    
    Whitespace between elements is ignored, ' sin ( 2 * x ) ' is equivalent to
    'sin(2*x)', but 's in(2*x)' is an error. Implied multiplication is not
    allowed, the expression '2x' will be parsed as a variable. Parentheses are
    (), do not use [] or {}. Functions require parentheses, the expression 'sin
    x' is an error.
    
    The following functions are supported:
    
    sin: 1 argument, the sine of the argument (units are radians)
    cos: 1 argument, the cosine of the argument (units are radians)
    tan: 1 argument, the tangent of the argument (units are radians)
    asin: 1 argument, the inverse of sine of the argument, in radians
    acos: 1 argument, the inverse of cosine of the argument, in radians
    atan: 1 argument, the inverse of tangent of the argument, in radians
    atan2: 2 arguments, atan2(y, x) returns the inverse of tangent of (y/x), in
    radians, determining quadrant by the sign of both arguments
    sinh: 1 argument, the hyperbolic sine of the argument
    cosh: 1 argument, the hyperbolic cosine of the argument
    tanh: 1 argument, the hyperbolic tangent of the argument
    asinh: 1 argument, the inverse hyperbolic sine of the argument
    acosh: 1 argument, the inverse hyperbolic cosine of the argument
    atanh: 1 argument, the inverse hyperbolic tangent of the argument
    sinc: 1 argument, sinc(0) = 1, sin(x) / x otherwise
    ln: 1 argument, the natural logarithm of the argument
    exp: 1 argument, the constant e raised to the power of the argument
    log: 1 argument, the base 10 logarithm of the argument
    log2: 1 argument, the base 2 logarithm of the argument
    sqrt: 1 argument, the square root of the argument
    abs: 1 argument, the absolute value of the argument
    floor: 1 argument, the largest integer not greater than the argument
    round: 1 argument, the nearest integer, with ties rounded away from zero
    ceil: 1 argument, the smallest integer not less than the argument
    min: 2 arguments, min(x, y) returns y if (x > y), x otherwise
    max: 2 arguments, max(x, y) returns y if (x < y), x otherwise
    mod: 2 arguments, mod(x, y) = x - y * floor(x / y), or 0 if y == 0
    clamp: 3 arguments, clamp(x, low, high) = min(max(x, low), high)
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        expression: the expression to evaluate, in quotes.
        cifti_out: the output cifti file.
        opt_fixnan_replace: replace NaN results with a value: value to replace\
            NaN with.
        opt_override_mapping_check: don't check the mappings for compatibility,\
            only check length.
        var: a cifti file to use as a variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiMathOutputs`).
    """
    params = cifti_math_params(
        expression=expression,
        cifti_out=cifti_out,
        opt_fixnan_replace=opt_fixnan_replace,
        opt_override_mapping_check=opt_override_mapping_check,
        var=var,
    )
    return cifti_math_execute(params, runner)


__all__ = [
    "CIFTI_MATH_METADATA",
    "CiftiMathOutputs",
    "cifti_math",
    "cifti_math_execute",
    "cifti_math_params",
    "cifti_math_select_params",
    "cifti_math_var_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_MATCH_METADATA = Metadata(
    id="975e55b50cc859adc6088f990f927b4229a7b26c.boutiques",
    name="surface-match",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceMatchParameters = typing.TypedDict('SurfaceMatchParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-match"]],
    "match_surface_file": InputPathType,
    "input_surface_file": InputPathType,
    "output_surface_name": str,
})
SurfaceMatchParametersTagged = typing.TypedDict('SurfaceMatchParametersTagged', {
    "@type": typing.Literal["workbench/surface-match"],
    "match_surface_file": InputPathType,
    "input_surface_file": InputPathType,
    "output_surface_name": str,
})


class SurfaceMatchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceMatchParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_match_params(
    match_surface_file: InputPathType,
    input_surface_file: InputPathType,
    output_surface_name: str,
) -> SurfaceMatchParametersTagged:
    """
    Build parameters.
    
    Args:
        match_surface_file: Match (Reference) Surface.
        input_surface_file: File containing surface that will be transformed.
        output_surface_name: Surface File after transformation.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-match",
        "match_surface_file": match_surface_file,
        "input_surface_file": input_surface_file,
        "output_surface_name": output_surface_name,
    }
    return params


def surface_match_cargs(
    params: SurfaceMatchParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-match")
    cargs.append(execution.input_file(params.get("match_surface_file", None)))
    cargs.append(execution.input_file(params.get("input_surface_file", None)))
    cargs.append(params.get("output_surface_name", None))
    return cargs


def surface_match_outputs(
    params: SurfaceMatchParameters,
    execution: Execution,
) -> SurfaceMatchOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceMatchOutputs(
        root=execution.output_file("."),
    )
    return ret


def surface_match_execute(
    params: SurfaceMatchParameters,
    runner: Runner | None = None,
) -> SurfaceMatchOutputs:
    """
    surface-match
    
    Surface match.
    
    The Input Surface File will be transformed so that its coordinate ranges
    (bounding box) match that of the Match Surface File.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceMatchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_MATCH_METADATA)
    params = execution.params(params)
    cargs = surface_match_cargs(params, execution)
    ret = surface_match_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_match(
    match_surface_file: InputPathType,
    input_surface_file: InputPathType,
    output_surface_name: str,
    runner: Runner | None = None,
) -> SurfaceMatchOutputs:
    """
    surface-match
    
    Surface match.
    
    The Input Surface File will be transformed so that its coordinate ranges
    (bounding box) match that of the Match Surface File.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        match_surface_file: Match (Reference) Surface.
        input_surface_file: File containing surface that will be transformed.
        output_surface_name: Surface File after transformation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceMatchOutputs`).
    """
    params = surface_match_params(
        match_surface_file=match_surface_file,
        input_surface_file=input_surface_file,
        output_surface_name=output_surface_name,
    )
    return surface_match_execute(params, runner)


__all__ = [
    "SURFACE_MATCH_METADATA",
    "SurfaceMatchOutputs",
    "surface_match",
    "surface_match_execute",
    "surface_match_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_PAIRWISE_CORRELATION_METADATA = Metadata(
    id="028724c21d89b563d8ea997344bbbb94f43f23a0.boutiques",
    name="cifti-pairwise-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiPairwiseCorrelationParameters = typing.TypedDict('CiftiPairwiseCorrelationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-pairwise-correlation"]],
    "cifti_a": InputPathType,
    "cifti_b": InputPathType,
    "cifti_out": str,
    "opt_fisher_z": bool,
    "opt_override_mapping_check": bool,
})
CiftiPairwiseCorrelationParametersTagged = typing.TypedDict('CiftiPairwiseCorrelationParametersTagged', {
    "@type": typing.Literal["workbench/cifti-pairwise-correlation"],
    "cifti_a": InputPathType,
    "cifti_b": InputPathType,
    "cifti_out": str,
    "opt_fisher_z": bool,
    "opt_override_mapping_check": bool,
})


class CiftiPairwiseCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiPairwiseCorrelationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_pairwise_correlation_params(
    cifti_a: InputPathType,
    cifti_b: InputPathType,
    cifti_out: str,
    opt_fisher_z: bool = False,
    opt_override_mapping_check: bool = False,
) -> CiftiPairwiseCorrelationParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_a: first input cifti file.
        cifti_b: second input cifti file.
        cifti_out: output cifti file.
        opt_fisher_z: apply fisher small z transform (ie, artanh) to\
            correlation.
        opt_override_mapping_check: don't check the mappings for compatibility,\
            only check length.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-pairwise-correlation",
        "cifti_a": cifti_a,
        "cifti_b": cifti_b,
        "cifti_out": cifti_out,
        "opt_fisher_z": opt_fisher_z,
        "opt_override_mapping_check": opt_override_mapping_check,
    }
    return params


def cifti_pairwise_correlation_cargs(
    params: CiftiPairwiseCorrelationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-pairwise-correlation")
    cargs.append(execution.input_file(params.get("cifti_a", None)))
    cargs.append(execution.input_file(params.get("cifti_b", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_fisher_z", False):
        cargs.append("-fisher-z")
    if params.get("opt_override_mapping_check", False):
        cargs.append("-override-mapping-check")
    return cargs


def cifti_pairwise_correlation_outputs(
    params: CiftiPairwiseCorrelationParameters,
    execution: Execution,
) -> CiftiPairwiseCorrelationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiPairwiseCorrelationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_pairwise_correlation_execute(
    params: CiftiPairwiseCorrelationParameters,
    runner: Runner | None = None,
) -> CiftiPairwiseCorrelationOutputs:
    """
    cifti-pairwise-correlation
    
    Correlate paired rows between two cifti files.
    
    For each row in <cifti-a>, correlate it with the same row in <cifti-b>, and
    put the result in the same row of <cifti-out>, which has only one column.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiPairwiseCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_PAIRWISE_CORRELATION_METADATA)
    params = execution.params(params)
    cargs = cifti_pairwise_correlation_cargs(params, execution)
    ret = cifti_pairwise_correlation_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_pairwise_correlation(
    cifti_a: InputPathType,
    cifti_b: InputPathType,
    cifti_out: str,
    opt_fisher_z: bool = False,
    opt_override_mapping_check: bool = False,
    runner: Runner | None = None,
) -> CiftiPairwiseCorrelationOutputs:
    """
    cifti-pairwise-correlation
    
    Correlate paired rows between two cifti files.
    
    For each row in <cifti-a>, correlate it with the same row in <cifti-b>, and
    put the result in the same row of <cifti-out>, which has only one column.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_a: first input cifti file.
        cifti_b: second input cifti file.
        cifti_out: output cifti file.
        opt_fisher_z: apply fisher small z transform (ie, artanh) to\
            correlation.
        opt_override_mapping_check: don't check the mappings for compatibility,\
            only check length.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiPairwiseCorrelationOutputs`).
    """
    params = cifti_pairwise_correlation_params(
        cifti_a=cifti_a,
        cifti_b=cifti_b,
        cifti_out=cifti_out,
        opt_fisher_z=opt_fisher_z,
        opt_override_mapping_check=opt_override_mapping_check,
    )
    return cifti_pairwise_correlation_execute(params, runner)


__all__ = [
    "CIFTI_PAIRWISE_CORRELATION_METADATA",
    "CiftiPairwiseCorrelationOutputs",
    "cifti_pairwise_correlation",
    "cifti_pairwise_correlation_execute",
    "cifti_pairwise_correlation_params",
]
